<?php

class DatabaseQueries {

	public static function getColumnsName($id = true){
		global $db;
		$columnArray = [];
		$sql = "SHOW COLUMNS FROM ".static::$tableName;
		$columns = $db->execute($sql);
		foreach($columns as $column){
			$columnArray[] = $column->Field; 
		}
		if(!$id && in_array('id', $columnArray)){ array_shift($columnArray);}
		return $columnArray;
	}

	public static function findAll($direction = "ASC"){
		$sql  = "SELECT * FROM ".static::$tableName;
		$sql .= " ORDER BY id ".$direction;
		return static::findBySQL($sql);
	}

	public static function enumValues($column){
		global $db;
		$sql = "SHOW COLUMNS FROM ".static::$tableName." WHERE Field = :column";
		$stmt = $db->execute($sql, ['column' => $column]);
	    $result = $db->fetchObj($stmt);
	    $str = $result[0]->Type;
	    preg_match("%^enum\(\'(.*)\'\)$%", $str, $matches);
	    $arr = explode("','", $matches[1]);
	    return $arr;
	}

	public static function findById($id){
		$id = (int) $id;
		$array = ["id" => $id];
		$sql  = "SELECT * FROM ".static::$tableName;
		$sql .= " WHERE id = :id LIMIT 1";
		$result = static::findBySQL($sql, $array);
		return array_shift($result);
	}

	public static function findBySQL($sql, $array = array()){
		global $db;
		$stmt = $db->execute($sql, $array);
		$results = $db->fetchObj($stmt);
		$output = [];
		foreach($results as $result){
			$object = new static;
			foreach($result as $key => $value){
				if(property_exists($object, $key)){
					$object->$key = $value;
				}
			}
			array_push($output, $object);
		}

		return $output;
	}

	public static function countAll(){
		global $db;
		$sql = "SELECT COUNT(*) FROM ".static::$tableName;
		$stmt = $db->execute($sql);
		return $stmt->fetchColumn();
	}

	protected function dataAsArray($id = true){
		$result = [];
		$sqlData = [];
		$valuesData = [];
		$columnFields = static::getColumnsName();
		foreach($columnFields as $key => $value){
			if(property_exists($this, $value)){
				$sqlData[$value] = ":$value";
				$valuesData[$value] = $this->$value;
			}		
		}

		if(!$id && array_key_exists('id', $sqlData)){ array_shift($sqlData); array_shift($valuesData);}
		$result['sqlData'] = $sqlData;
		$result['valuesData'] = $valuesData;

		return $result;
	}

	public function save(){
		return (isset($this->id)) && is_int($this->id) ? $this->update() : $this->create();
	}

	public function create(){
		global $db;
        $data = $this->dataAsArray(false);
		$sql  = "INSERT INTO ".static::$tableName." (";
		$sql .= join(", ", array_keys($data['sqlData']));
		$sql .= ") VALUES (";
		$sql .= join(", ", array_values($data['sqlData']));
		$sql .= ")";
		if($db->execute($sql, $data['valuesData'])){
			$this->id = $db->lastInsertId();
			return true;
		}else{
			return false;
		}
	}

	public function update(){
		global $db;
		$data = $this->dataAsArray(false);
		$paired = [];

		foreach($data['sqlData'] as $key => $value){
			$paired[] = $key." = ".$value;
		}

		$sql  = "UPDATE ".static::$tableName." SET ";
		$sql .= join(", ", $paired);
		$sql .= " WHERE id = :id LIMIT 1";
		$data['valuesData']['id'] = (int) $this->id;
		return ($db->execute($sql, $data['valuesData'])) ? true : false;
	}

	public function delete(){
		global $db;
		$id = (int) $this->id;
		$sql  = "DELETE FROM ".static::$tableName;
		$sql .= " WHERE id = :id LIMIT 1";

		return ($db->execute($sql, ["id" => $id])) ? true : false;
	}


	public function lastInsertId(){
		global $db;
		return $db->lastInsertId();
	}
}