<?php

class images extends DatabaseQueries{
	public $id,
	       $user_id = 0,
	       $project_id = 0,
	       $filename,
	       $location,
	       $file4Unlink,
	       $type, 
	       $size,
	       $destination,
	       $order_img = 0,
	       $added_by,
	       $modified_by,
	       $date_added,
	       $date_modified;
	public static $tableName = "images";
	protected $processImg = [],
			  $messages = [],
			  $errors = [],
	          $source,
	          $permittedTypes = array(
	          	"image/jpeg",
	          	"image/jpg",
	          	"image/pjpeg",
	          	"image/gif",
	          	"image/png",
	          	"image/webp"
	          ),
	          $maxSize = 10485760,
	          $newName,
	          $invalid = [],
	          $outputSizes = [],
	          $jpegQuality = 75,
	          $pngCompression = 0,
	          $resample = IMG_BILINEAR_FIXED,
	          $watermark ,
	          $markW,
	          $markH,
	          $markType,
	          $marginR,
	          $marginB,
	          $renameDuplicates,
	          $useLongerDimension,
	          $generated = [];            

	public function __construct($source = null){
		if(!is_null($source) && !is_dir($source)){
			throw new Exception("$source is not a directory");
		}

		if($source[strlen($source)-1] != "/"){
			$source .= "/";
		}

		if(isset($_SESSION['userId'])){
			$this->customer_id = $_SESSION['userId'];
		}

		$this->destination = $source;
	} 

	public function setOutputSizes(array $sizes, $useLongerDimension = true){
		foreach($sizes as $size){
			if(!is_numeric($size) || $size <= 0){
				throw new Exception("Sizes must be an array of positive numbers.");
			}
			$this->outputSizes[] = (int) $size;
		}

		$this->useLongerDimension = $useLongerDimension;
	}

	public function setJpegQuality($number){
		if(!is_numeric($number) || $number < 0 || $number > 100){
			throw new Exception('JPG Quality must be a number in the range 0-100.');
		}
		$this->jpegQuality = $number;
	}

	public function setPngCompression($number){
		if(!is_numeric($number) || $number < 0 || $number > 9){
			throw new Exception('PNG Compression must be a number from 0(no compression) to 9.');
		}
		$this->pngCompression = $number;
	}

	public function setResamplingMethod($value){
		switch(strtolower($value)){
			case 'bicubic':
				$this->resample = IMG_BICUBIC;
				break;
			case 'bicubic-fixed':
				$this->resample = IMG_BICUBIC_FIXED;
				break;
			case 'nearest-neighbour':
			case 'nearest-neighbor':
				$this->resample = IMG_NEAREST_NEIGHBOUR;
			default:
				$this->resample = IMG_BILINEAR_FIXED; 
		}
	}

	public function watermark($filepath, $marginRight = 30, $marginBottom = 30){
		if(!file_exists($filepath) || !is_readable($filepath)){
			throw new Exception("Cannot access watermark image at $filepath.");
		}
		$size = getimagesize($filepath);
		if(!in_array($size['mime'], $this->permittedTypes)){
			throw new Exception('watermark must be one of the following: '.implode(', ', $this->permittedTypes));
		}

		$this->watermark = $this->createImageResource($filepath, $size['mime']);
		$this->markW = $size[0];
		$this->markH = $size[1];

		if(is_numeric($marginRight) && $marginRight > 0){
			$this->marginR = $marginRight;
		}

		if(is_numeric($marginBottom) && $marginBottom > 0){
			$this->marginR = $marginRight;
		}
	}

	public function outputImages(){
		$resource = $this->createImageResource($this->processImg['file'], $this->processImg['type']);
		if($this->watermark){
			$this->addWatermark($this->processImg, $resource);
		}

		$this->generateOutput($this->processImg, $resource);
		imagedestroy($resource);

	}

	public function setMaxSize($bytes){
		$serverLimit = self::convertToBytes(ini_get('upload_max_filesize'));
		if($bytes > $serverLimit){
			throw new Exception('Maximum size cannot exceed server limit for individual files: '.self::convertFromBytes($serverLimit));
		}
		if(is_numeric($bytes) && $bytes > 0){
			$this->maxSize = $bytes;
		}
	}

	public function upload($renameDuplicates = true){
		$this->renameDuplicates = $renameDuplicates;
		$file = current($_FILES);
		if(is_array($file['name'])){
			foreach($file['name'] as $key => $value){
				$current['name'] = $file['name'][$key];
				$current['type'] = $file['type'][$key];
				$current['tmp_name'] = $file['tmp_name'][$key];
				$current['error'] = $file['error'][$key];
				$current['size'] = $file['size'][$key];
				$this->order_img++;
				if($this->checkFile($current)){
					$this->moveFile($current, $key);
				}
			}
		}else{
			$this->order_img++;
			if($this->checkFile($file)){
				$this->moveFile($file);
			}
		}

	}

	public function getMessages(){
		return $this->messages;
	}

	public static function convertToBytes($val){
		$val = trim($val);
		$last = strtolower($val[strlen($val)-1]);
		if(in_array($last, ['g', 'm', 'k']) && preg_match('/\d+/', $val, $matched)){
			$val = $matched[0];
			switch($last){
				case 'g':
					$val *= 1024;
				case 'm':
					$val *= 1024;
				case 'k':
					$val *= 1024;
			}
		}

		return $val;
	}

	public static function convertFromBytes($bytes){

		$bytes /= 1024;
		if($bytes > 1024){
			return number_format($bytes/1024, 1).'MB';
		}else{
			return number_format($bytes, 1)."KB";
		}
	}

	protected function createImageResource($file, $type){
		switch($type){
			case 'image/jpeg':
				return imagecreatefromjpeg($file);
			case 'image/png':
				return imagecreatefrompng($file);
			case 'image/gif':
				return imagecreatefromgif($file);
			case 'image/webp':
				return imagecreatefromwebp($file);
		}
	}

	protected function addWatermark(array $image, $resource){
		$x = $image['w'] - $this->markW - $this->marginR;
		$y = $image['h'] - $this->markH - $this->marginB;
		
		imagecopy($resource, $this->watermark, $x , $y, 0, 0, $this->markW, $this->markH);
	}

	protected function checkFile($file){
		if($file['error'] != 0){
			$this->getErrorMessage($file);
			return false;
		}

		if(!$this->checkSize($file)){ return false; }
		if(!$this->checkType($file)){ return false; }
		$this->checkName($file);
		return true;
	}

	protected function checkType($file){
		if((getimagesize($file['tmp_name']) > 0) && in_array($file['type'], $this->permittedTypes)){
			$this->type = $file['type'];
			return true;
		}else{
			$this->errors[] = $file['name'].' is not of permitted types.';
			return false;
		}
	}

	protected function checkName($file){
		$this->newName = null;
		$noSpace = str_replace(' ', '_', $file['name']);
		$noSpace = str_replace("'", "", $noSpace);
		$noSpace = str_replace('"', "", $noSpace);
		if($noSpace != $file['name']){
			$this->newName = $noSpace;
		}

		if($this->renameDuplicates){
			$name = isset($this->newName) ? $this->newName : $file['name'];
			$directory = scandir($this->destination);
			$nameparts = pathinfo($noSpace);
			if(in_array($name, $directory)){
				$i = 1;
				do{
					$this->newName = $nameparts['filename'].'_'.$i++;
					$this->newName .= '.'.$nameparts['extension'];
				}while(in_array($this->newName, $directory));
			}
		}

		$this->filename = isset($this->newName) ? $this->newName : $file['name'];
	}

	protected function getErrorMessage($file){
		switch($file['error']){
			case 1:
			case 2:
				$this->errors[] = $file['name'].' is too big (max: '.self::convertFromBytes($this->maxSize).').';
				break;
			case 3:
				$this->errors[] = $file['name'].' was only partially uploaded';
				break;
			case 4:
				$this->errors[] = $file['name'].' no file provided.';
				break;
			default:
				$this->errors[] = 'Sorry, there was a problem uploading '.$file['name'];
		}
	}

	protected function checkSize($file){
		if($file['size'] == 0){
			$this->errors[] = $file['name']." is empty."; 
			return false;
		}else if($file['size'] > $this->maxSize){
			$this->errors[] = $file['name'].' exceeds the maximum size for a file ('.self::convertFromBytes($this->maxSize).').';
			return false;
		}else{
			$this->size = $file['size'];
			return true;
		}
	}

	protected function checkJpegOrientation($image, $size){
		$outputFile = $image;
		//@ symbol helps to ignore Incorrect APP1 Exif Identifier Code error
		$exif = @exif_read_data($image);
		if(!empty($exif['Orientation'])){
			switch($exif['Orientation']){
				case 3: 
					$angle = 180;
					break;
				case 6:
				    $angle = -90;
				    break;
				case 8:
					$angle = 90;
					break;
				default: 
					$angle = null;
			}

			if(!is_null($angle)){
				$resource = imagecreatefromjpeg($image);
				$rotated = imagerotate($resource, $angle, 0);
				//save the rotated image with new name
				$ext = pathinfo($image, PATHINFO_EXTENSION);
				$outputFile = str_replace(".$ext", "_rotated.jpg", $image);
				imagejpeg($rotated, $outputFile, 100);
				$size = getimagesize($outputFile);
				imagedestroy($resource);
				imagedestroy($rotated);
			}
		}

		return ['file' => $outputFile, 'size' => $size];
	}

	protected function generateOutput($image, $resource){
		$storedSizes = $this->outputSizes;
		$nameParts = pathinfo($image['file']);
		$w = imagesx($resource);
		$h = imagesy($resource);
		if($this->useLongerDimension && $h > $w){
			$this->recalculateSizes($resource);
		}

		foreach($this->outputSizes as $outputSize){
			if($outputSize > $image['w']){ continue; }

			if($image['type'] == "image/png"){
				$h2 = round($h * $outputSize/$w);
				$scaled = imagecreatetruecolor($outputSize, $h2);
			    imagealphablending($scaled, false);
			    imagesavealpha($scaled, true);
				imagecopyresampled($scaled, $resource, 0, 0, 0, 0, $outputSize, $h2, $w, $h);
			}else{
				$scaled = imagescale($resource, $outputSize, -1, $this->resample);
			}

			if($outputSize > 0 && $outputSize <= 160){
				$filename = $nameParts['filename'].'_thumbnail'.$outputSize.'.'.$nameParts['extension'];
			}else{
				$filename = $nameParts['filename'].'_'.$outputSize.'.'.$nameParts['extension'];
			}
			$this->outputFile($scaled, $image['type'], $filename); 
		}

		$this->outputSizes = $storedSizes;
	}

	protected function recalculateSizes($resource){
		$w = imagesx($resource);
		$h = imagesy($resource);
		foreach($this->outputSizes as &$size){
			$size = round($size * $w / $h, 0);
		}
	}

	protected function outputFile($scaled, $type, $name){
		$success = false;
		$outputFile = $this->destination.DS.$name;
		switch($type){
			case 'image/jpeg':
				$success = imagejpeg($scaled, $outputFile, $this->jpegQuality);
				break;
			case 'image/png':
			    $success = imagepng($scaled, $outputFile, $this->pngCompression);
			    break;
			case 'image/gif':
				$success = imagegif($scaled, $outputFile);
				break;
			case 'image/webp':
				$success = imagewebp($scaled, $outputFile);
		}
		imagedestroy($scaled);
	}

	protected function moveFile($file, $key = 0){
		$name = isset($this->newName) ? $this->newName : $file['name'];
		if(move_uploaded_file($file['tmp_name'], $this->destination.$name)){
			$size = getimagesize($this->destination.$name);
			$this->processImg['file'] =  $this->destination.$name;
			$this->processImg['type'] = $size['mime'];
			if($size['mime'] == "image/jpeg"){
				$results = $this->checkJpegOrientation($this->processImg['file'], $size);
				$this->processImg['file'] = $results['file'];
				$size = $results['size'];  
			}
			$this->processImg['w'] = $size[0];
			$this->processImg['h'] = $size[1];
			array_push($this->outputSizes, $size[0]);
			$this->outputImages();
			if($key !== 0 && isset($this->id)){
				$this->id = null;
			}
			if($this->save()){
				$this->messages['result'] = "success";
				$this->messages['msg'] = $file['name']."  was successfully uploaded.";
				return true;
			}else{
				$this->errors[] = $file['name']." profile picture setup failed.";
			}
			return false;
		}else{
			$this->errors[] = $file['name'].' upload failed, try again.';
		}

		return false;
	}

	public function errors(){
		return $this->errors;
	}

	public function update(){
		$dest = $this->destination.$this->file4Unlink;
		if(parent::update() && $this->file4Unlink){
			$this->unlink($dest);
		}

		return true;
	}

	public function unlink($path){
		$nameParts = pathinfo($path);
		$dir = dirname($path);
		$images = new FilesystemIterator($dir);
		$regEx = '/'.$nameParts['filename'].'(_rotated)?(_\d+)?(_thumbnail\d+)?\.'.$nameParts['extension'].'$/';
		$images = new RegexIterator($images, $regEx);
		foreach($images as $image){
			$file = $dir.DS.$image->getFilename();
			if(is_file($file)){
				unlink($file);
			}
		}
	}

	public function destroy($path){
		if($this->delete()){ $this->unlink($path); }
	}
}

