<?php
class MySQLDB {
    private $pdo;

    public function __construct(){
        $this->openConnection();
    }

    private function openConnection(){
        $dsn = sprintf("mysql:host=%s;dbname=%s", DB_SERVER, DB_NAME);

        try {
            $this->pdo = new PDO($dsn, DB_USER, DB_PASS);
            $this->pdo->setAttribute(PDO::ATTR_DEFAULT_FETCH_MODE, PDO::FETCH_OBJ);

            //in order to use the LIMIT clause as variable we have to turn off emulation mode
            $this->pdo->setAttribute(PDO::ATTR_EMULATE_PREPARES, false);
        }catch(PDOException $e){
            die($e->getMessage());
        }
    }

    public function prepare($sql){
        return $this->pdo->prepare($sql);
    }

    public function execute($sql, $array = []){
        $stmt = $this->prepare($sql);
        if($stmt->execute($array)){
            return $stmt;
        }else{
            $error = $stmt->errorInfo();
            die("Database Connection failed: ".$error[2]);
        }
    }

    public function fetchObj($stmt){
        return $stmt->fetchAll();
    }

    public function rowCount($stmt){
        return $stmt->rowCount();
    }

    public function lastInsertId(){
        //works after an insert query
        return $this->pdo->lastInsertId();
    } 

    public function closeConnection(){
        $this->pdo = null;
    }
}

$database = new MySQLDB();
$db =& $database;