<?php

class Session{

	private $loggedIn = false,
	        $hash,
	        $message;
	public $userId,
	       $passedData;

	public function __construct(Hash $hash){
		/*
		* string provided in the session name should be simple and alphanumeric. 
		* where numbers provided should at least have one letter
		*/
		session_name("jamruch");
		session_start();
		$this->hash = $hash;
		$this->checkLogin();
		$this->checkMessage();
	}

	public function isLoggedIn(){
		return $this->loggedIn;
	}

	public function logIn($user){
		if($user){
			session_regenerate_id(); //prevent session hijacking and fixiation
			$this->userId = $_SESSION['userId'] = $user->id;
			$this->loggedIn = true;
			if($user->confirm_token !== ""){
				$user->confirm_token = "";
				$user->date_modified = strftime("%Y-%m-%d %H:%M:%S", time());
				$user->save();
			}
		}
	}

	public function logOut(){
		$_SESSION = array();
		session_destroy();
		setcookie('jamruch', "", (time() -(60*60*24*7)));
		unset($this->userId);
		$this->loggedIn = false;
	}

/*

	public function setLastInsertId($table, $id){
		$_SESSION[$table] = $id;
	}

	public function getLastInsertId($table){
		if(isset($_SESSION[$table])){
			$lastInsertId = $_SESSION[$table];
			return $lastInsertId;
		}

		return "";
	}
*/

	private function checkLogin(){
		if(isset($_SESSION['userId'])){
			$this->userId = $_SESSION['userId'];
			$this->loggedIn = true;
		}
	}

	private function checkMessage(){
		if(isset($_SESSION['message'])){
			$this->message = $_SESSION['message'];
			unset($_SESSION['message']);
		}else{
			$this->message = "";
		}
	}

	private function passedData(){
		if(isset($_SESSION['passedData'])){
			$this->passedData = $_SESSION['passedData'];
			unset($_SESSION['passedData']);
		}else{
			$this->passedData = "";
		}
	}

	public function message($message = ""){
		if(!empty($message)){
			$_SESSION['message'] = $message;
		}else{
			return $this->message; 
		}
	}

	public function data($data = ""){
		if(!empty($data)){
			$_SESSION['passedData'] = $data;
		}else{
			$this->passedData();
			return $this->passedData;
		}
	}

	public function createToken($name, $timerName){
		$token = $this->hash->salt();
		$_SESSION[$name] = $token;
		$_SESSION[$timerName] = time();
		return $token;
	}

	public function destroyToken($name, $timerName){
		$_SESSION[$name] = null;
		$_SESSION[$timerName] = null;
		return true;
	}

	public function tokenIsValid($name, $timerName, $maxTime = (60 * 60 * 2)){
		if(isset($_SESSION[$timerName])){
			return ((int)$_SESSION[$timerName] + (int)$maxTime) >= time();
		}else{
			$this->destroyToken($name, $timerName);
			return false;
		}
	}	
}

$session = new Session($hash);
$message = $session->message();