<?php
use PHPMailer\PHPMailer\PHPMailer;

spl_autoload_register(function($class){
    $path = LIB_PATH.$class.".php";

    if(file_exists($path)){
        require_once $path;
    }
});

function redirect($direction = ""){
	if(!empty($direction)){
		header("Location: ".$direction);
		exit;
	}
}

function tryToSendEmail($email = "", $name = "", $body = ""){
	$mail = new PHPMailer();  // Passing `true` enables exceptions
    //Server settings
    //$mail->SMTPDebug = 3;                                 // Enable verbose debug output
    $mail->isSMTP();                                      // Set mailer to use SMTP
    $mail->Host = 'mail.jamruchrealestates.co.ke';  // Specify main and backup SMTP servers
    //$mail->Port = 25;
    $mail->SMTPAuth = true;                               // Enable SMTP authentication
    $mail->Username = 'info@jamruchrealestates.co.ke';          // SMTP username
    $mail->Password = EMAIL_PASS;                          // SMTP password
    $mail->SMTPSecure = 'ssl';                            // Enable TLS encryption, `ssl` also accepted
    $mail->Port = 465;  // TCP port to connect to
    /*$mail->SMTPOptions = array(
	    'ssl' => array(
	        'verify_peer' => false,
	        'verify_peer_name' => false,
	        'allow_self_signed' => true
	    )
	);*/                                  
    $mail->addReplyTo('sales@jamruchrealestates.co.ke', 'jamruchrealestates.co.ke');
    $mail->setFrom('sales@jamruchrealestates.co.ke', 'jamruchrealestates.co.ke');
    $mail->addAddress($email, $name);     // Add a recipient

    //Content
    $mail->isHTML(true);                                  // Set email format to HTML
    $mail->Subject = 'jamruchrealestates.co.ke notification';
    $mail->Body    = $body;
    $mail->AltBody = strip_tags($body);

    $result = $mail->send();

    //incase we what to test if the email was sent successful
    return $result;
}

function inputErrCheck($value){
	if(isset($value) && !empty($value)){
		return "error-input";
	}

	return "";
}

function priviledged($user){
	if(strtolower($user->user_group) == "admin"){
		return "very strong";
	}else if(strtolower($user->user_group) == "admin" || strtolower($user->user_group) == "moderator"){
		return "strong";
	}

	return "weak";
}

function dashboardPriviledged($session){
	if(!$session->isLoggedIn()){ redirect(PUBLIC_FOLDER); }
	$user = User::findById($session->userId);
	if(priviledged($user) === "weak"){ redirect(PUBLIC_FOLDER); }
	return $user;
}

function compareUsersPriviledges($current, $focus){
	$perms = array(
		"admin" => 3,
		"moderator" => 2,
		"standard" => 1
	);

    if((int)$perms[strtolower($current->user_group)] > (int)$perms[strtolower($focus->user_group)]){
    	return true;
    }

    return false;

}

function getProfilePicture($user, $path, $size = "full"){
	if($user->image != 0){
		$img = Images::findById($user->image);
		$img = getImgs($img->id, $path, $size);
		return $img;
	}

	return $path."avatar.png";
}

function isAjaxRequest(){
	return isset($_SERVER['HTTP_X_REQUESTED_WITH']) && $_SERVER['HTTP_X_REQUESTED_WITH'] == "XMLHttpRequest";
}

function getImgs($imgId, $path = 'img'."/".'users'."/", $key = "full"){
    $output = [];
    $image = Images::findById($imgId);
    if(is_object($image)){
        $path .= $image->filename;
        $nameParts = pathinfo($path);
        $dir = dirname($path);
        $images = new FilesystemIterator($dir);
        $regEx = '/'.$nameParts['filename'].'(_rotated)?(_\d+)?(_thumbnail\d+)?\.'.$nameParts['extension'].'$/';
        $images = new RegexIterator($images, $regEx);
        $m = [];
        $pattern = '/_(\d+)\.'.$nameParts['extension'].'$/';
        $thumbNPtn = '/_thumbnail\d+\.'.$nameParts['extension'].'$/';
        $fullPtn = '/_rotated\.'.$nameParts['extension'].'$/';
        foreach($images as $image){
            $file = $dir."/".$image->getFilename();
            if($nameParts['filename'] !== pathinfo($file)['filename']){
                preg_match($pattern, $file, $match);
                if(isset($match[1])){ $m[$match[1]] = $file;}

                if(preg_match($fullPtn, $file)){  $output['full'] = $file;}

                if(preg_match($thumbNPtn, $file)){  $output['thumbnail'] = $file;}
            }
        }

        if(!isset($output['full'])){ $output['full'] = $path; }
        if(!empty($m)){
            $minKey = min(array_keys($m));
            $output['min'] = $m[$minKey];
            $maxKey = max(array_keys($m));
            $output['max'] = $m[$maxKey];
        }
        
    }

    if($key == "max" && array_key_exists($key, $output)){
        return $output["max"];
    }else if($key == "max" && !array_key_exists($key, $output)){
        return $output["full"];
    }

    if($key == "min" && array_key_exists($key, $output)){
        return $output['min'];
    }else if($key == "min" && !array_key_exists($key, $output)){
        if(array_key_exists("thumbnail", $output)){
            return $output["thumbnail"];
        }
    }

    if($key == "thumbnail" && array_key_exists($key, $output)){
        return $output["thumbnail"];
    }

    return $output["full"];
}

function datetimeToTime($date = ""){
    if(!empty($date)){
        $time = strtotime($date);
        return strftime("%d %b'%y %H:%M", $time);
    }
}

function cleanURLForms($url){
	$pathParts = pathinfo($url);
	return htmlentities($pathParts['dirname'].DS.$pathParts['filename']);
}

function lastSeen($session){
	if($session->isLoggedIn()){
		$user = User::findById($session->userId);
		$user->last_seen = strftime("%Y-%m-%d %H:%M:%S");
		$user->save();
	}
}

function tagsAllowed(){
    $tags = array(
        "<p>", "<b>", "<br>", "<blockquote>", "<caption>", "<cite>", 
        "<code>", "<div>", "<em>", "<strong>", "<fieldset>", "<figcaption>",
        "figure", "footer", "<header>", "<h1>", "<h2>", "<h3>", "<h4>", "<h5>",
        "<h6>", "<img>", "<i>", "<kbd>", "<ul>", "<li>", "<main>", "<mark>", "<nav>",
        "<ol>", "<optgroup>", "<option>", "<output>", "<picture>", "<pre>", "<progress>",
        "<section>", "<small>", "<span>", "<source>", "<del>", "<s>", "<sub>", "<summary",
        "<svg>", "<table>", "<thead>", "<tbody>", "<td>", "<th>", "<tr>", "<tfoot>", "<time>",
        "<video>", "<hr>"
    );

    return implode("", $tags);
}

function getWatermark($path = '../img/watermark/', $key = "min"){
    $sql = "SELECT * FROM images WHERE location = :type AND order_img = :order LIMIT 1";
    $watermark = Images::findBySQL($sql, ["type" => "watermark", "order" => 1]);
    $watermark = array_pop($watermark);
    $result = getImgs($watermark->id, $path, $key = "min");
    return $result;
}

function sliders4HTML($path = "img/slider/"){
    $sql = "SELECT * FROM images WHERE location = :type ORDER BY order_img ASC";
    $sliders = Images::findBySQL($sql, ["type" => "slider"]);
    $result = [];
    foreach($sliders as $slider){
        array_push($result, getImgs($slider->id, $path, $key = "max"));
    }

    return json_encode($result);
}

function projectName4HTMLID($project){
    return htmlentities(str_replace(" ", "-", strtolower(trim($project->name ?? $project->title))));
}

function displayProjectAccordion($errors = [], $key = ""){

    if(isset($errors['key']) && $errors['key'] === $key){ 
        return "show"; 
    }else if(!isset($errors['key']) && $key === 0){
        return "show";
    } 

    return "";

}

function projectOutputErr($errors, $key){
    if(isset($errors['key']) && $errors['key'] === $key){
        return true;
    }

    return false;
}

function msgSeen($msg){
    if($msg->seen === 0){
        return "bg-dark";
    }

    return "bg-light text-dark";
}

function imgUrl($url){
    $url = substr($url, strpos($url, "img/"));

    return substr(PUBLIC_FOLDER, 0, strlen(PUBLIC_FOLDER)).$url;
}