<?php 
require_once "../includes/init.php";
if($session->isLoggedIn()){ redirect("jamruch_admin/"); }

if(isset($_POST['login']) && $_SESSION['logIn'] == $_POST['token'] && 
	$session->tokenIsValid('logIn', 'logInTimer')){
	$post = array(
		"email" => $_POST['email'],
		"password" => $_POST['password'] 
	);
	extract($post);

	$fields = array(
		"email" => array(
			"name" => "email",
			"required" => true,
			"validate" => "email"
		),
		"password" => array(
			"name" => "password",
			"required" => true
		)
	);

	$validate = new Validate();
	$validate->check($post, $fields);
	if(!$validate->passed()){
		$errors = $validate->errors();
		$emailErr = $errors['email'] ?? "";
		$passwordErr = $errors['password'] ?? "";

	}else{
		$user = new User();
		$user = $user->authenticate(trim(strtolower($email)), $password);
		if($user){
			$session->logIn($user);
			$logger = new Logger('../logs/successful_login.log');
			$logMsg = $user->fullName()." successfully logged in";
			$logger->logAction('Login', $logMsg);
			redirect('jamruch_admin/');
		}else{
			$error = "login failed, please try again.";
			$logger = new Logger('../logs/failed_login.log');
			$logMsg = $_POST['email']." failed to logged in";
			$logger->logAction('Login', $logMsg);
		}
	}
}


if(isset($_POST['request']) && $_SESSION['forgotPass'] == $_POST['forgot-pass-token'] && 
	$session->tokenIsValid('forgotPass', 'forgotPassTimer')){
	$post = array(
		"email" => trim(strtolower($_POST['email']))
	);
	extract($post);

	$fields = array(
		"email" => array(
			"name" => "email",
			"required" => true,
			"validate" => "email"
		)
	);

	$validate = new Validate();
	$validate->check($post, $fields);
	if(!$validate->passed()){
		$errors = $validate->errors();
		$requestEmailErr = $errors['email'] ?? "";
	}else{
		$sql = "SELECT * FROM users WHERE email = :email LIMIT 1";
		$user = User::findBySQL($sql, ['email' => $email]);
		if(count($user) == 1){
			$user = array_shift($user);
			$token = $hash->salt(95);
			$body = "Hi ".htmlspecialchars($user->first_name).",<br><br>";
		    $body .= "<p>click the button below to confirm you want to set a new password.</p><br>";
		    $body .= "<a href='https://jamruchrealestates.co.ke/reset/".htmlspecialchars($user->email)."/".$token."'";
		    $body .=  "style='background-color:#00FF00;font-size:14px;color:#ffffff;text-decoration:none;border-radius:4px;padding:16px 22px;border:1px solid #006666;display:inline-block;max-width:348px'";
		    $body .= "'>Confirm</a>";
		    $user->confirm_token = $token;
		    $user->date_modified = strftime("%Y-%m-%d %H:%M:%S", time());
		    $user->save();
		    $error = "";
			if(tryToSendEmail($user->email, $user->first_name, $body)){
	           $error .= "<p class=\"alert alert-success\">";
	           $error .= "Check your email to reset your password. ";
	           $error .= "If you don't see it in the inbox check it in the spam folder";
	           $error .= "</p>";
            }else{
               $error .= "<p  class=\"error-msg\">";
               $error .= "A problem occurred, contact for account activation.";
               $error .= "</p>";
            }
		}
	}
}

?>
<?php require_once "layout/header.php"; ?>
<div class="container">
	<form id="login-form" action="jamruch_access.php" method="post" class="mt-3">
		<div class="msg-display"><?php echo $error ?? ""; ?></div>
		<div class="form-group">
			<div id="erremail" class="error-msg"><?php echo htmlspecialchars($emailErr ?? "");?></div>
			<label class="form-control-label" for="emaillogin">Email</label>
			<input class="form-control <?php echo inputErrCheck($emailErr ?? ""); ?>" type="text" id="emaillogin" name="email" placeholder="email" value="">
		</div>
		<div class="form-group">
			<div id="errpassword" class="error-msg"><?php echo htmlspecialchars($passwordErr ?? "");?></div>
			<label for="passlogin" class="form-control-label">password</label>
			<input class="form-control <?php echo inputErrCheck($passwordErr ?? ""); ?>" type="password" id="passlogin" name="password" placeholder="password" value="">
		</div>
		<div class="form-group">
			<input type="hidden" id="logInToken" name="token" value="<?php echo $session->createToken('logIn', 'logInTimer'); ?>">
			<input type="submit" name="login" value="login" class="btn btn-primary" id="loginbtn">
		</div>
		<span data-toggle="modal" data-target="#forgot-pass-form-div" id="forgot-pass">
			forgot your password?
		</span>
	</form>

	<div id="forgot-pass-form-div" class="modal fade" tabindex="-1" role="dialog">
		<div class="modal-dialog" role="document">
			<form id="forgot-pass-form" action="/access" method="post" class="modal-content">
				<span id="forgot-pass-err">Enter email address that you signed up for the account.</span>
				<button type="button" class="close" data-dismiss="modal" arial-label="close">
					<span aria-hidden="true">&times;</span>
				</button>
				<div class="form-group">
					<div id="forgot-pass-err-email" class="error-msg"><?php echo htmlspecialchars($requestEmailErr ?? "");?></div>
					<label for="forgot-pass-email" class="form-control-label">Email</label>
					<input type="text" class="form-control <?php echo inputErrCheck($requestEmailErr ?? ""); ?>" id="forgot-pass-email" name="email" placeholder="email" value="">
				</div>
				<div class="form-group">
					<input type="hidden" id="forgot-pass-token" name="forgot-pass-token" value="<?php echo $session->createToken('forgotPass', 'forgotPassTimer'); ?>">
					<input type="submit" name="request" value="request" class="btn btn-primary" id="request-btn">
				</div>
			</form>
		</div>
	</div>
</div>

<?php if(isset($requestEmailErr)){ ?>
<script>
	window.addEventListener('DOMContentLoaded', ()=>{
		let forgotPass = document.querySelector('#forgot-pass');
			forgotPass.click();
	});


</script>
<?php } ?>

<?php require_once "layout/footer.php"; ?>