<?php 
require_once "../../includes/init.php";
$user = dashboardPriviledged($session);

$errors = [];


if(isset($_POST['update-amenity']) && $_POST['update-amenity'] && ctype_digit($_POST['amenity-id']) && 
	$_POST['amenity-id'] != 0 && $_POST['token'] === $_SESSION['amenityUpdateToken'] &&
	$session->tokenIsValid('amenityUpdateToken', 'amenityUpdateTimer')){

	$fields = array(
		'name' => array(
			'name' => 'amenity name',
			'required' => true,
			'unique' => 'name',
			'change' => true,
			'max' => 50,
			'min' => 2
		),
		'icon' => array(
			'name' => 'icon',
			'required' => true,
			'validate' => 'special /^<i class="icon-info-blocks material-icons">[\w]+<\/i>$/',
			'max' => 100,
			'min' => 2
		),
		'description' => array(
			'name' => 'description',
			'required' => true,
			'max' => 255,
			'min' => 10
		)
	);

	$msg = '<div class="alert alert-danger alert-dismissible fade show text-center" role="alert">';
	$msg .=	'Unable to update project, try again!';
	$msg .=	'<button type="button" class="close" data-dismiss="alert" aria-label="Close">';
	$msg .= '<span aria-hidden="true">&times;</span>';
	$msg .= '</button>';
	$msg .=	'</div>';

    $amenity = Amenity::findById($_POST['amenity-id']);

    if(is_object($amenity)){
    	$validate = new Validate('Amenity', $amenity->id);
		$validate->check($_POST, $fields);
		$errors = $validate->errors();

		if(!empty($errors)){
			$errors['key'] = array_search($amenity, $amenities);
		}

		if(empty($errors)){

			if($amenity){
				$amenity->icon = $_POST['icon'];
				$amenity->name = $_POST['name'];
				$amenity->description = $_POST['description'];
				if($amenity->save()){
					$msg = '<div class="alert alert-primary alert-dismissible fade show text-center" role="alert">';
					$msg .=	'<button type="button" class="close" data-dismiss="alert" aria-label="Close">';
					$msg .=	'<span aria-hidden="true">&times;</span>';
					$msg .= '</button>';
					$msg .= 'Amenity was updated successful.';
					$msg .=	'</div>';

				}
			}
		}

    }

}

$amenities = Amenity::findAll();

?>

<?php 
require_once "../layout/admin_header.php";
require_once "../layout/panel_header.php"; 
?>
<div class="container">
	<div class="mt-3">
		<?php echo $msg ?? ""; ?>
	</div>
	<h2 class="text-center mt-2">Amenities</h2>
	<div id="add-amenities-btn" class="text-right h3" role="button" data-toggle="modal" data-target="#add-amenities-div">
		<i class="fa fa-plus" aria-hidden="true"></i>
	</div>
	<div class="modal fade text-dark" id="add-amenities-div" data-backdrop="static" tabindex="-1" role="dialog" aria-labelledby="add-amenities-modal-label" aria-hidden="true">
		<div class="modal-dialog" role="document">
	    	<div class="modal-content">
	      		<div class="modal-header">
	        		<h5 class="modal-title" id="add-amenities-modal-label">Add Amenities</h5>
	        		<button type="button" class="close" data-dismiss="modal" aria-label="Close">
	          			<span aria-hidden="true">&times;</span>
	        		</button>
	      		</div>
	      		<div class="modal-body">
	        		<form id="add-amenities-form">
	        			<div class="form-group">
	        				<div class="error-msg" id="icon-error"></div>
	            			<label for="amenities-icon" class="col-form-label">Icon:</label>
	            			<input type="text" class="form-control" id="amenities-icon" name="amenitiesicon">
	          			</div>
	          			<div class="form-group">
	          				<div class="error-msg" id="name-error"></div>
	            			<label for="amenities-name" class="col-form-label">Name:</label>
	            			<input type="text" class="form-control" id="amenities-name" name="amenitiesname">
	          			</div>
	          			<div class="form-group">
	          				<div class="error-msg" id="description-error"></div>
	            			<label for="amenities-description" class="col-form-label">Description:</label>
	            			<textarea class="form-control" id="amenities-description" name="amenitiesdescription"></textarea>
	          			</div>
	          			<div class="form-group">
	            			<input type="hidden" name="amenitiestoken" value="<?php echo $session->createToken("addAmenitiesToken", "addAmenitiesTimer");?>">
	          			</div>
	        		</form>
	      		</div>
	      		<div class="modal-footer">
			        <button id="add-amenities-submit" type="button" name="addamenitiessubmit" class="btn btn-primary">Add</button>
	      		</div>
	    	</div>
	  	</div>
    </div>
</div>

<?php if(!empty($amenities)){ $amenityUpdateToken = $session->createToken('amenityUpdateToken', 'amenityUpdateTimer'); ?>
	<div  id="amenities-container" class="accordion mt-3">
	<?php foreach($amenities as $key => $amenity){?>
		<div class="card bg-light">
			<div class="card-header row" id="<?php echo projectName4HTMLID($amenity);?>-heading">
				<h3 class="mb-0 col">
					<button class="btn btn-primary" type="button" data-toggle="collapse" 
					data-target="#<?php echo projectName4HTMLID($amenity); ?>" aria-expanded="true" aria-controls="<?php echo projectName4HTMLID($amenity);?>">
			          <?php echo htmlentities($amenity->name); ?>
			        </button>
			    </h3>
			    <div class="delete-amenity ml-3 col text-right" data-amenity="<?php echo $amenity->id; ?>" data-amenitytoken="<?php echo $amenityUpdateToken; ?>">
                	<a href="" class="text-danger"><i class="fa fa-trash-o"></i></a>
                </div>
			</div>
			<div id="<?php echo projectName4HTMLID($amenity);?>" class="collapse <?php echo displayProjectAccordion($errors, $key); ?>" aria-labelledby="<?php echo projectName4HTMLID($amenity);?>-heading" data-parent="#amenities-container">
				<div class="row card-body">
					<div class="col-12">
						<form action="" method="POST" class="amenities-form bg-dark p-3 rounded">
				          	<div class="form-group">
				          		<div class="error-msg">
									<?php if(projectOutputErr($errors, $key)){ echo htmlspecialchars($errors['icon'] ?? "");} ?>
								</div>
				            	<input type="text" class="form-control <?php if(projectOutputErr($errors, $key)){ echo inputErrCheck($errors['icon'] ?? ""); } ?>" name="icon" placeholder="Amenity Name" value='<?php echo strip_tags($amenity->icon, '<i>');  ?>'>
				          	</div>
				          	<div class="form-group">
				          		<div class="error-msg">
								<?php if(projectOutputErr($errors, $key)){ echo htmlspecialchars($errors['name'] ?? ""); }?>
								</div>
				          		<input type="text" name="name" class="form-control <?php if(projectOutputErr($errors, $key)){echo inputErrCheck($errors['name'] ?? ""); } ?>" placeholder="name" value="<?php  echo htmlentities($amenity->name ?? ""); ?>">
				          	</div>
					        <div class="form-group">
				          		<div class="error-msg">
									<?php if(projectOutputErr($errors, $key)){echo htmlspecialchars($errors['description'] ?? ""); } ?>
								</div>
					            <textarea class="form-control  <?php if(projectOutputErr($errors, $key)){ echo inputErrCheck($errors['description'] ?? "");}?>" name="description"><?php echo htmlentities($amenity->description ?? "Descprition"); ?>
					            </textarea>
					        </div>
				          <div class="form-group text-center">
				          	<input type="hidden" name="amenity-id" value="<?php echo $amenity->id; ?>">
				          	<input type="hidden" class="amenity-update-token" name="token" value="<?php echo $amenityUpdateToken; ?>">
				        	<button type="submit" class="btn btn-primary" name="update-amenity" value="true">Update Project</button>
				          </div>
						</form>
					</div>
				</div>
			</div>
		</div>
	<?php } ?>
<?php } else { ?>
	<div>No amenities found!</div>
<?php } ?>

<?php 
require_once "../layout/admin_footer.php";
require_once "../layout/panel_footer.php"; 
?>