<?php 
require_once "../../includes/init.php";
$user = dashboardPriviledged($session);

$errors = [];

if(isset($_POST['add-post']) && $_POST['post-token'] === $_SESSION['addPostToken'] && $session->tokenIsValid('addPostToken', 'addPostTimer')){
	

	$fields = array(
		'title' => array(
			'name' => 'title',
			'required' => true,
			'unique' => 'title',
			'max' => 50,
			'min' => 2
		),
		'body' => array(
			'name' => 'post body',
			'required' => true,
			'max' => 5000,
			'min' => 10
		)
	);

	$validate = new Validate('Post');
	$validate->check($_POST, $fields);
	$errors = $validate->errors();

	if(empty($errors)){
		$post = new Post();
		$post->title = strtolower($_POST['title']);
		$post->body = $_POST['body'];
		$post->date_added = strftime("%Y-%m-%d %H:%M:%S");
		$post->added_by = $user->id;

		if($post->save()){
			
			$msg = '<div class="alert alert-primary alert-dismissible fade show text-center" role="alert">';
			$msg .=	'<button type="button" class="close" data-dismiss="alert" aria-label="Close">';
			$msg .=	'<span aria-hidden="true">&times;</span>';
			$msg .= '</button>';
			$msg .= 'Post added successful.';
			$msg .=	'</div>';
		}else{
			$msg = '<div class="alert alert-danger alert-dismissible fade show text-center" role="alert">';
			$msg .=	'Unable to add post, try again!';
			$msg .=	'<button type="button" class="close" data-dismiss="alert" aria-label="Close">';
			$msg .= '<span aria-hidden="true">&times;</span>';
			$msg .= '</button>';
			$msg .=	'</div>';
		}

	}


}

$posts = Post::findAll('DESC');

if(isset($_POST['update-post']) && $_POST['token'] === $_SESSION['postUpdateToken'] && 
	$session->tokenIsValid('postUpdateToken', 'postUpdateTimer') && ctype_digit($_POST['post-id']) && $_POST['post-id'] != 0){
	$fields = array(
		'title' => array(
			'name' => 'title',
			'required' => true,
			'unique' => 'title',
			'change' => true,
			'max' => 50,
			'min' => 2
		),
		'body' => array(
			'name' => 'post body',
			'required' => true,
			'max' => 5000,
			'min' => 10
		)
	);

	$msg = '<div class="alert alert-danger alert-dismissible fade show text-center" role="alert">';
	$msg .=	'Unable to update post, try again!';
	$msg .=	'<button type="button" class="close" data-dismiss="alert" aria-label="Close">';
	$msg .= '<span aria-hidden="true">&times;</span>';
	$msg .= '</button>';
	$msg .=	'</div>';

    $post = Post::findById($_POST['post-id']);

    if(is_object($post)){
    	$validate = new Validate('Post', $post->id);
		$validate->check($_POST, $fields);
		$errors = $validate->errors();

		if(empty($errors)){

			if($post){
				$post->title = strtolower($_POST['title']);
				$post->body = $_POST['body'];
				$post->date_modified = strftime("%Y-%m-%d %H:%M:%S");
				$post->modified_by = $user->id;
				if($post->save()){
					$msg = '<div class="alert alert-primary alert-dismissible fade show text-center" role="alert">';
					$msg .=	'<button type="button" class="close" data-dismiss="alert" aria-label="Close">';
					$msg .=	'<span aria-hidden="true">&times;</span>';
					$msg .= '</button>';
					$msg .= 'Post was updated successful.';
					$msg .=	'</div>';

					$posts = Post::findAll('DESC');
				}
			}
		}else{
			$errors['key'] = array_search($post, $posts);
		}

    }
}


?>
<?php 
require_once "../layout/admin_header.php";
require_once "../layout/panel_header.php"; 
?>

<div class="container">
	<div class="mt-3">
		<?php echo $msg ?? ""; ?>
	</div>
	<h2 class="text-center mt-2">Posts</h2>
	<div id="add-post-btn" class="text-right h3" role="button" data-toggle="modal" data-target="#add-posts-div">
		<i class="fa fa-plus" aria-hidden="true"></i>
	</div>
	<div class="modal fade text-dark" id="add-posts-div" data-backdrop="static" tabindex="-1" role="dialog" aria-labelledby="add-posts-modal-label" aria-hidden="true">
		<div class="modal-dialog modal-lg" role="document">
	    	<div class="modal-content">
	    		<form action="" method="POST">
		      		<div class="modal-header">
		        		<h5 class="modal-title" id="add-posts-modal-label">Add Post</h5>
		        		<button type="button" class="close" data-dismiss="modal" aria-label="Close">
		          			<span aria-hidden="true">&times;</span>
		        		</button>
		      		</div>
		      		<div class="modal-body">
		        			<div class="form-group">
		        				<div class="error-msg" id="name-error">
		        					<?php echo htmlentities($errors['title'] ?? ""); ?>
		        				</div>
		            			<label for="post-name" class="col-form-label">Name:</label>
		            			<input type="text" class="form-control <?php echo inputErrCheck($errors['title'] ?? ""); ?>" id="post-name" name="title">
		          			</div>
		          			<div class="form-group">
		          				<div class="error-msg" id="description-error">
		          					<?php echo htmlentities($errors['body'] ?? ""); ?>
		          				</div>
		            			<label for="post-description" class="col-form-label">Description:</label>
		            			<textarea class="form-control <?php echo inputErrCheck($errors['body'] ?? ""); ?>" id="post-description" name="body"></textarea>
		          			</div>
		          			<div class="form-group">
		            			<input type="hidden" name="post-token" value="<?php echo $session->createToken("addPostToken", "addPostTimer");?>">
		          			</div>
		      		</div>
		      		<div class="modal-footer">
				        <button id="add-post" type="submit" name="add-post" value="true" class="btn btn-primary">Add</button>
		      		</div>
	      		</form>
	    	</div>
	  	</div>
    </div>
</div>

<?php if(!empty($posts)){ $postUpdateToken = $session->createToken('postUpdateToken', 'postUpdateTimer'); ?>
	<div  id="posts-container" class="accordion mt-3">
	<?php foreach($posts as $key => $post){?>
		<div class="card bg-light">
			<div class="card-header row" id="<?php echo projectName4HTMLID($post);?>-heading">
				<h3 class="mb-0 col">
					<button class="btn btn-primary" type="button" data-toggle="collapse" 
					data-target="#<?php echo projectName4HTMLID($post); ?>" aria-expanded="true" aria-controls="<?php echo projectName4HTMLID($post);?>">
			          <?php echo htmlentities($post->title); ?>
			        </button>
			    </h3>
			    <div class="delete-post ml-3 col text-right" data-post="<?php echo $post->id; ?>" data-posttoken="<?php echo $postUpdateToken; ?>">
                	<a href="" class="text-danger"><i class="fa fa-trash-o"></i></a>
                </div>
			</div>
			<div id="<?php echo projectName4HTMLID($post);?>" class="collapse <?php echo displayProjectAccordion($errors, $key); ?>" aria-labelledby="<?php echo projectName4HTMLID($post);?>-heading" data-parent="#posts-container">
				<div class="row card-body">
					<div class="col-12">
						<form action="" method="POST" class="posts-form bg-dark p-3 rounded" class="update-posts-form">
				          	<div class="form-group">
				          		<div class="error-msg">
									<?php if(projectOutputErr($errors, $key)){ echo htmlentities($errors['title'] ?? "");} ?>
								</div>
				            	<input type="text" class="form-control <?php if(projectOutputErr($errors, $key)){ echo inputErrCheck($errors['title'] ?? ""); } ?>" name="title" placeholder="post name" value='<?php echo htmlentities($post->title);  ?>'>
				          	</div>
				          	<div class="form-group">
				          		<div class="error-msg">
								<?php if(projectOutputErr($errors, $key)){ echo htmlentities($errors['body'] ?? ""); }?>
								</div>
				          		<textarea name="body" class="form-control update-posts-textarea <?php if(projectOutputErr($errors, $key)){echo inputErrCheck($errors['body'] ?? ""); } ?>">
				          			<?php  echo htmlentities($post->body ?? "post body"); ?>
				          		</textarea>
				          	</div>
				          <div class="form-group text-center">
				          	<input type="hidden" name="post-id" value="<?php echo $post->id; ?>">
				          	<input type="hidden" class="post-update-token" name="token" value="<?php echo $postUpdateToken; ?>">
				        	<button type="submit" class="btn btn-primary" name="update-post" value="true">Update Post</button>
				          </div>
						</form>
					</div>
				</div>
			</div>
		</div>
	<?php } ?>
<?php } else { ?>
	<div>No Post found!</div>
<?php } ?>

<?php if(isset($errors) && !empty($errors) && !isset($errors['key']) && !isset($msg)){ ?>
<script>
	window.addEventListener('DOMContentLoaded', ()=>{
		let addPostBtn = document.querySelector('#add-post-btn');
			addPostBtn.click();
	});

</script>
<?php } ?>
<?php 
require_once "../layout/admin_footer.php";
require_once "../layout/panel_footer.php"; 
?>