<?php 
require_once "../../includes/init.php";
$user = dashboardPriviledged($session);
$max = Images::convertToBytes(ini_get('upload_max_filesize'));
$errors = [];

if(isset($_POST['add-project']) && $_POST['upload-project-imgs-token'] === $_SESSION['uploadProjectImgsToken']
	&& $session->tokenIsValid('uploadProjectImgsToken', 'uploadProjectImgsTimer')){
	$fields = array(
		'name' => array(
			'name' => 'project name',
			'required' => true,
			'unique' => 'name',
			'max' => 50,
			'min' => 2
		),
		'price-input' => array(
			'name' => 'price',
			'required' => true,
			'validate' => 'numbers',
			'max' => 23,
			'min' => 2
		),
		'size-input' => array(
			'name' => 'size',
			'required' => true,
			'max' => 100,
			'min' => 3
		),
		'project-location' => array(
			'name' => 'Location',
			'required' => true,
			'max' => 100,
			'min' => 3
		),
		'project-description' => array(
			'name' => 'description',
			'required' => true,
			'max' => 5000,
			'min' => 3
		)
	);

	$validate = new Validate('Project');
	$validate->check($_POST, $fields);
	$errors = $validate->errors();

	if(empty($errors)){
		$project = new Project();
		$project->name = $_POST['name'];
		$project->price = $_POST['price-input'];
		$project->size = $_POST['size-input'];
		$project->location = $_POST['project-location'];
		$project->description = $_POST['project-description'];
		$project->added_by = $user->id;
		$project->modified_by = 0;
		$project->date_added = strftime("%Y-%m-%d %H:%M:%S");
		$project->date_modified = strftime("%Y-%m-%d %H:%M:%S");
		if($project->save()){
			$img = new Images("../img/projects/");
			$img->user_id = 0;
			$img->project_id = $project->id;
			$img->location = "projects";
			$img->watermark(getWatermark());
			$img->setOutputSizes([160, 350, 500]);
			$img->added_by = $user->id;
			$img->modified_by = 0;
			$img->date_added = strftime("%Y-%m-%d %H:%M:%S");
			$img->date_modified = strftime("%Y-%m-%d %H:%M:%S");
			$img->upload();
			$imgErr = !empty($img->errors()) ? $img->errors()[0] : "";
			if(!empty($imgErr)){
				$errors["upload-project-imgs"] = $imgErr;
				$project->delete();
			} else {
				$msg = '<div class="alert alert-primary alert-dismissible fade show text-center" role="alert">';
				$msg .=	'<button type="button" class="close" data-dismiss="alert" aria-label="Close">';
				$msg .=	'<span aria-hidden="true">&times;</span>';
				$msg .= '</button>';
				$msg .= 'Project was added successful.';
				$msg .=	'</div>';
			}
		}else{
			$msg = '<div class="alert alert-danger alert-dismissible fade show text-center" role="alert">';
			$msg .=	'Unable to add project, try again!';
			$msg .=	'<button type="button" class="close" data-dismiss="alert" aria-label="Close">';
			$msg .= '<span aria-hidden="true">&times;</span>';
			$msg .= '</button>';
			$msg .=	'</div>';
		}

	}

}


$sql = "SELECT * FROM images WHERE location = :type ORDER BY order_img ASC";
$projectImgs = Images::findBySQL($sql, ["type" => "projects"]);
$projects = Project::findAll();

if(isset($_POST['update-project']) && $_POST['update-project'] && ctype_digit($_POST['project-id']) && 
	$_POST['project-id'] != 0 && $_POST['project-update-token'] === $_SESSION['uploadImgsToken'] &&
	$session->tokenIsValid('uploadImgsToken', 'uploadImgsTimer')){

	$fields = array(
		'name' => array(
			'name' => 'project name',
			'required' => true,
			'unique' => 'name',
			'change' => true,
			'max' => 50,
			'min' => 2
		),
		'price-input' => array(
			'name' => 'price',
			'required' => true,
			'validate' => 'numbers',
			'max' => 23,
			'min' => 2
		),
		'size-input' => array(
			'name' => 'size',
			'required' => true,
			'max' => 100,
			'min' => 3
		),
		'project-location' => array(
			'name' => 'Location',
			'required' => true,
			'max' => 100,
			'min' => 3
		),
		'project-description' => array(
			'name' => 'description',
			'required' => true,
			'max' => 5000,
			'min' => 3
		)
	);

    $project = Project::findById($_POST['project-id']);

    if(is_object($project)){
    	$validate = new Validate('Project', $project->id);
		$validate->check($_POST, $fields);
		$errors = $validate->errors();

		if(!empty($errors)){
			$errors['key'] = array_search($project, $projects);
		}

		if(empty($errors)){

			if($project){
				$project->name = $_POST['name'];
				$project->price = $_POST['price-input'];
				$project->size = $_POST['size-input'];
				$project->location = $_POST['project-location'];
				$project->description = $_POST['project-description'];
				$project->modified_by = $user->id;
				$project->date_modified = strftime("%Y-%m-%d %H:%M:%S");
				if($project->save()){
					$msg = '<div class="alert alert-primary alert-dismissible fade show text-center" role="alert">';
					$msg .=	'<button type="button" class="close" data-dismiss="alert" aria-label="Close">';
					$msg .=	'<span aria-hidden="true">&times;</span>';
					$msg .= '</button>';
					$msg .= 'Project was updated successful.';
					$msg .=	'</div>';
					$projects = Project::findAll();

					$file = current($_FILES);

					if(!empty($file) && is_array($file) && is_array($file['error']) && $file['error'][0] !== 4){

						$sql = "SELECT * FROM images WHERE project_id = :pid";

						$countImgs = Images::findBySQL($sql, ["pid" => $project->id]);
						$imgAdd = new Images("../img/projects/");
						$imgAdd->user_id = 0;
						$imgAdd->project_id = $project->id;
						$imgAdd->location = "projects";
						$imgAdd->order_img = count($countImgs);
						$imgAdd->watermark(getWatermark());
						$imgAdd->setOutputSizes([160, 350, 500]);
						$imgAdd->added_by = $user->id;
						$imgAdd->modified_by = 0;
						$imgAdd->date_added = strftime("%Y-%m-%d %H:%M:%S");
						$imgAdd->date_modified = strftime("%Y-%m-%d %H:%M:%S");
						$imgAdd->upload();
						$imgAddErr = !empty($imgAdd->errors()) ? $imgAdd->errors()[0] : "";
						
						if(!empty($imgAddErr)){
							$errors["add-project-imgs"] = $imgAddErr;
							$projects = Project::findAll();
							$project = Project::findById($project->id);
							$errors['key'] = array_search($project, $projects);
							$msg = "";
						} else {
							$file = current($_FILES);
							$num = is_array($file['name']) ? count($file['name']) : 1;
							$msg .= '<div class="alert alert-primary alert-dismissible fade show text-center" role="alert">';
							$msg .=	'<button type="button" class="close" data-dismiss="alert" aria-label="Close">';
							$msg .=	'<span aria-hidden="true">&times;</span>';
							$msg .= '</button>';
							$msg .= 'Image';
							$msg .= $num > 1 ? 's were' : ' was';
							$msg .= ' added successful.';
							$msg .=	'</div>';
						}

					}

				}else{
					$msg = '<div class="alert alert-danger alert-dismissible fade show text-center" role="alert">';
					$msg .=	'Unable to update project, try again!';
					$msg .=	'<button type="button" class="close" data-dismiss="alert" aria-label="Close">';
					$msg .= '<span aria-hidden="true">&times;</span>';
					$msg .= '</button>';
					$msg .=	'</div>';
				}
			}else{
				$msg = '<div class="alert alert-danger alert-dismissible fade show text-center" role="alert">';
				$msg .=	'Unable to update project, try again!';
				$msg .=	'<button type="button" class="close" data-dismiss="alert" aria-label="Close">';
				$msg .= '<span aria-hidden="true">&times;</span>';
				$msg .= '</button>';
				$msg .=	'</div>';
			}
		}

    } else {
		$msg = '<div class="alert alert-danger alert-dismissible fade show text-center" role="alert">';
		$msg .=	'Unable to update project, try again!';
		$msg .=	'<button type="button" class="close" data-dismiss="alert" aria-label="Close">';
		$msg .= '<span aria-hidden="true">&times;</span>';
		$msg .= '</button>';
		$msg .=	'</div>';
    }

}


?>
<?php 
require_once "../layout/admin_header.php";
require_once "../layout/panel_header.php"; 
?>

<div class="container">
	<div id="lg-pic-modal" class="pic-modal">
		<span class="img-close">&times;</span>
		<img class="pic-modal-content" id="lg-pic">
		<div id="pic-caption" class="caption d-none"></div>
		<div id="upload-pic-details" class="d-none text-center mt-3">
			<div id="showPercent"></div>
			<div id="showProgress"></div>
			<button id="uploadPicBtn" class="btn btn-primary">UPLOAD</button>
		</div>
	</div>
	<div id="add_project_container" class="text-dark">
		<div class="modal fade" id="add_project" data-backdrop="static" tabindex="-1" role="dialog" aria-labelledby="exampleModalLabel" aria-hidden="true">
		  <div class="modal-dialog  modal-lg" role="document">
		    <div class="modal-content">
		      <div class="modal-header">
		        <h5 class="modal-title" id="exampleModalLabel">ADD A PROJECT.</h5>
		        <button type="button" class="close" data-dismiss="modal" aria-label="Close">
		          <span aria-hidden="true">&times;</span>
		        </button>
		      </div>
		      <div class="modal-body">
		        <form method="POST" action="" enctype="multipart/form-data">
		          <div class="form-group">
		          	<div id="name-msg" class="error-msg">
						<?php echo htmlspecialchars($errors['name'] ?? "");?>
					</div>
		            <label for="name" class="col-form-label">Project Name:</label>
		            <input type="text" class="form-control <?php echo inputErrCheck($errors['name'] ?? ""); ?>" name="name" id="name" placeholder="Project Name" value="<?php if(!empty($errors)){ echo htmlentities($project->name ?? ""); } ?>">
		          </div>
		          	<div class="form-row">
			          	<div class="col form-group">
			          		<div id="price-msg" class="error-msg">
							<?php echo htmlspecialchars($errors['price-input'] ?? "");?>
						</div>
			          		<label for="price-input">Price</label>
			          		<input id="price-input" type="text" name="price-input" class="form-control <?php echo inputErrCheck($errors['price-input'] ?? ""); ?>" placeholder="Price" value="<?php if(!empty($errors)){ echo htmlentities($project->price ?? ""); } ?>">
			          	</div>
			          	<div class="col form-group">
			          			<div id="price-msg" class="error-msg">
									<?php echo htmlspecialchars($errors['size-input'] ?? "");?>
								</div>
			          		<label for="size-input">Size</label>
			          		<input id="size-input" type="text" name="size-input" class="form-control <?php echo inputErrCheck($errors['size-input'] ?? ""); ?>" placeholder="Size" value="<?php if(!empty($errors)){ echo htmlentities($project->size ?? ""); } ?>">
			          	</div>
		          	</div>
		          	<div class="form-group">
						<div id="project-location-msg" class="error-msg">
						<?php echo htmlspecialchars($errors['project-location'] ?? "");?>
						</div>
						<label for="project-location" class="col-form-label">Project Location:</label>
						<input type="text" class="form-control <?php echo inputErrCheck($errors['project-location'] ?? ""); ?>" name="project-location" id="project-location" placeholder="Project Location" value="<?php if(!empty($errors)){ echo htmlentities($project->location ?? ""); } ?>">
					</div>
		          	<div class="form-group">
		          		<div id="price-msg" class="error-msg">
							<?php echo htmlspecialchars($errors['project-description'] ?? "");?>
						</div>
		            <label for="project-description" class="col-form-label">Descprition:</label>
		            <textarea class="form-control  <?php echo inputErrCheck($errors['project-description'] ?? ""); ?>" name="project-description" id="project-description">
		            	<?php if(!empty($errors)){ echo htmlentities($project->description ?? ""); } ?>
		            </textarea>
		          </div>
		          <div class="form-group">
		          	<div class="img-errors text-danger">
		          		<?php echo htmlspecialchars($errors['upload-project-imgs'] ?? "");?>
		          	</div>
		          	<div id="displayProjectImgs" class="text-danger"></div>
		          	<input type="hidden" id="upload-project-imgs-token" name="upload-project-imgs-token" value="<?php echo $session->createToken('uploadProjectImgsToken', 'uploadProjectImgsTimer'); ?>">
					<input id="maxFileSize" type="hidden" name="MAX_FILE_SIZE" value="<?php echo htmlentities($max); ?>">
					<input type="file" accept="image/*" id="upload-project-imgs" name="upload-project-imgs[]" multiple data-maxPostFiles="<?php echo htmlentities($max);?>" class="form-control-file upload-imgs">
					<label for="upload-project-imgs" class="<?php echo inputErrCheck($errors['upload-project-imgs'] ?? ""); ?>">
						<i class="fa fa-upload btn btn-primary" aria-hidden="true"> UPLOAD IMAGES</i>
					</label>
		          </div>
		      </div>
		      <div class="modal-footer">
		        <button type="submit" class="btn btn-primary" name="add-project" value="true">ADD Project</button>
		      </div>
		  	  </form>
		    </div>
		  </div>
		</div>
	</div>
	<div class="container-fluid">
		<div class="mt-3">
			<?php echo $msg ?? ""; ?>
		</div>
		<div class="mt-3 text-right">
			<button id="add-project-btn" type="button" class="btn btn-primary" data-toggle="modal" data-target="#add_project"><i class="fa fa-plus" aria-hidden="true"></i></button>
		</div>
		<div  id="imgs-container" class="accordion mt-3">
			<?php if(!empty($projects)){ $projectsUpdateToken = $session->createToken('uploadImgsToken', 'uploadImgsTimer'); ?>
				<?php foreach($projects as $key => $project){?>
				<div class="card bg-light">
					<div class="card-header row" id="<?php echo projectName4HTMLID($project);?>-photos-heading">
						<h3 class="mb-0 col">
							<button class="btn btn-primary" type="button" data-toggle="collapse" 
							data-target="#<?php echo projectName4HTMLID($project); ?>" aria-expanded="true" aria-controls="<?php echo projectName4HTMLID($project);?>-photos">
					          <?php echo htmlentities($project->name); ?>
					        </button>
					    </h3>
					    <div class="delete-project ml-3 col text-right" data-project="<?php echo $project->id; ?>" data-projecttoken="<?php echo $projectsUpdateToken; ?>">
                        	<a href="" class="text-danger"><i class="fa fa-trash-o"></i></a>
                        </div>
					</div>
					<div id="<?php echo projectName4HTMLID($project);?>" class="collapse <?php echo displayProjectAccordion($errors, $key); ?> project-photos" aria-labelledby="<?php echo projectName4HTMLID($project);?>-photos-heading" data-parent="#imgs-container">
						<?php 
							$sql = "SELECT * FROM images WHERE project_id = :pid AND location = :type ORDER BY order_img ASC";
							$currentImgs = Images::findBySQL($sql, ["pid" => $project->id, "type" => "projects"]);
						?>
						<div class="row card-body" data-count="<?php echo count($currentImgs); ?>">
							<div class="col-12">
								<form action="" method="POST" class="projects-form bg-dark p-3 rounded" enctype="multipart/form-data">
						          <div class="form-group">
						          	<div class="error-msg">
										<?php if(projectOutputErr($errors, $key)){ echo htmlentities($errors['name'] ?? "");} ?>
									</div>
						            <input type="text" class="form-control <?php if(projectOutputErr($errors, $key)){ echo inputErrCheck($errors['name'] ?? ""); } ?>" name="name" placeholder="Project Name" value="<?php echo htmlentities($project->name ?? "");  ?>">
						          </div>
						          	<div class="form-row">
							          	<div class="col form-group">
							          		<div class="error-msg">
											<?php if(projectOutputErr($errors, $key)){ echo htmlspecialchars($errors['price-input'] ?? ""); }?>
										</div>
							          		<input type="text" name="price-input" class="form-control <?php if(projectOutputErr($errors, $key)){echo inputErrCheck($errors['price-input'] ?? ""); } ?>" placeholder="Price" value="<?php  echo htmlentities($project->price ?? ""); ?>">
							          	</div>
							          	<div class="col form-group">
						          			<div class="error-msg">
												<?php if(projectOutputErr($errors, $key)){echo htmlspecialchars($errors['size-input'] ?? ""); } ?>
											</div>
							          		<input type="text" name="size-input" class="form-control <?php if(projectOutputErr($errors, $key)){ echo inputErrCheck($errors['size-input'] ?? ""); } ?>" placeholder="Size" value="<?php echo htmlentities($project->size ?? ""); ?>">
							          	</div>
						          	</div>
						          	<div class="form-group">
										<div class="error-msg">
										<?php if(projectOutputErr($errors, $key)){ echo htmlspecialchars($errors['project-location'] ?? ""); } ?>
										</div>
										<input type="text" class="form-control <?php if(projectOutputErr($errors, $key)){ echo inputErrCheck($errors['project-location'] ?? "");} ?>" name="project-location" placeholder="Project Location" value="<?php echo htmlentities($project->location ?? ""); ?>">
									</div>
						          	<div class="form-group">
						          		<div class="error-msg">
											<?php if(projectOutputErr($errors, $key)){echo htmlspecialchars($errors['project-description'] ?? ""); } ?>
										</div>
						            <textarea class="form-control  <?php if(projectOutputErr($errors, $key)){ echo inputErrCheck($errors['project-description'] ?? "");}?>" name="project-description">
						            	<?php echo htmlentities(strip_tags($project->description, tagsAllowed()) ?? "Descprition"); ?>
						            </textarea>
						          </div>
						          <div class="m-2">
						          	<div class="img-errors text-danger">
						          		<?php if(projectOutputErr($errors, $key)){ echo htmlspecialchars($errors['add-project-imgs'] ?? "");}?>
						          	</div>
									<div class="additional-imgs m-3 text-danger"></div>									
									<input type="file" accept="image/*" id="add-project-img-<?php echo $key; ?>" class="add-project-imgs form-control-file upload-imgs" name="add-project-imgs[]" multiple data-maxPostFiles="<?php echo htmlentities($max);?>">
									<label for="add-project-img-<?php echo $key; ?>" class="<?php if(projectOutputErr($errors, $key)){ echo inputErrCheck($errors['add-project-imgs'] ?? "");} ?>">
										<i class="fa fa-upload btn btn-primary" aria-hidden="true"> ADD IMAGES</i>
									</label>
								  </div>
						          <div class="form-group text-center">
						          	<input type="hidden" name="project-id" value="<?php echo $project->id; ?>">
						          	<input type="hidden" class="project-update-token" name="project-update-token" value="<?php echo $projectsUpdateToken; ?>">
						        	<button type="submit" class="btn btn-primary" name="update-project" value="true">Update Project</button>
						          </div>
								</form>
							</div>
							<?php if(!empty($currentImgs)){ ?>
								<?php foreach($currentImgs as $currentImg){?>
								<div class="col-lg-3 col-md-4 col-xs-6 thumb">
					                <a class="<?php echo projectName4HTMLID($project);?>-imgs thumbnail" href="#" data-image-id="" data-toggle="modal" data-title="<?php echo htmlentities($currentImg->filename); ?>"
					                   data-image="<?php echo htmlentities(getImgs($currentImg->id, "../img/projects/", "max")); ?>"
					                   data-target="#image-gallery" data-num="<?php echo $currentImg->order_img; ?>"
					                   data-image-reg="<?php echo $currentImg->id; ?>">
					                    <img class="img-thumbnail" src="<?php echo htmlentities(getImgs($currentImg->id, "../img/projects/", "thumbnail")); ?>" alt="<?php echo htmlentities($currentImg->filename); ?>">
					                </a>
					            </div>
					            <?php } ?>
					        <?php } ?>
						</div>
					</div>
				</div>
				<?php } ?>
        	<?php } else { ?>
        		<div>No Projects Found</div> 
        	<?php } ?>
	        <div class="modal fade" id="image-gallery" tabindex="-1" role="dialog" aria-labelledby="myModalLabel" aria-hidden="true">
	            <div class="modal-dialog modal-lg">
	                <div class="modal-content">
	                    <div class="modal-header">
	                        <h4 class="modal-title" id="image-gallery-title"></h4>
                        	<button type="button" id="image-gallery-close" class="close" data-dismiss="modal">
	                        	<span aria-hidden="true">×</span>
	                        	<span class="sr-only">Close</span>
	                        </button>
	                        <div class="ml-3">
	                        	<select class="form-control-sm" id="image-gallery-count" data-current-reg=""></select>
	                        </div>
	                        <div class="delete-imgs ml-3 text-danger">
	                        	<a href=""><i class="fa fa-trash-o"></i></a>
	                        </div>
	                    </div>
	                    <div class="modal-body text-center">
	                        <img id="image-gallery-image" class="img-responsive col-md-10" src="">
	                    </div>
	                    <div class="modal-footer">
	                        <button type="button" class="btn btn-secondary float-left" id="show-previous-image"><i class="fa fa-arrow-left"></i>
	                        </button>

	                        <button type="button" id="show-next-image" class="btn btn-secondary float-right"><i class="fa fa-arrow-right"></i>
	                        </button>
	                    </div>
	                </div>
	            </div>
	        </div>
		</div>
	</div>
</div>

<?php if(isset($errors) && !empty($errors) && !isset($errors['key']) && !isset($msg)){ ?>
<script>
	window.addEventListener('DOMContentLoaded', ()=>{
		let addProjectBtn = document.querySelector('#add-project-btn');
			addProjectBtn.click();
	});


</script>
<?php } ?>

<?php 
require_once "../layout/admin_footer.php";
require_once "../layout/panel_footer.php"; 
?>
