<?php 
require_once "../../includes/init.php";
$current = dashboardPriviledged($session);
$users = User::findAll();
$enumValues = User::enumValues('user_group');
if(in_array($current, $users)){
	$pos = array_search($current, $users);
	array_splice($users, $pos, 1);

}


if(isset($_POST['add']) && $_SESSION['addUserToken'] === $_POST['token'] && $session->tokenIsValid('addUserToken', 'addUserTimer')){
	$fields = array(
		'email' => array(
			'name' => 'email',
			'required' => true,
			'validate' => 'email',
			'unique' => 'email'
		),
		'first-name' => array(
			'name' => 'first name',
			'required' => true,
			'min' => 2,
			'max' => 12
		),
		'last-name' => array(
			'name' => 'last name',
			'required' => true,
			'min' => 2,
			'max' => 12
		),
		'user-group' => array(
			'name' => 'user_group',
			'required' => true
		)
	);

	$validate = new Validate('User');
	$validate->check($_POST, $fields);
	$errors = $validate->errors();

	if(!in_array($_POST['user-group'], $enumValues)){
		$errors['user-group'] = "Check your user group value.";
	}
	if(empty($errors)){
		$password = $hash->salt(15);
		$newUser = new User();
		$newUser->first_name = $_POST['first-name'];
		$newUser->last_name = $_POST['last-name'];
		$newUser->email = $_POST['email'];
		$newUser->password = $hash->encrypter($password);
		$newUser->active = true;
		$newUser->user_group = $_POST['user-group'];
		$newUser->confirm_token = "";
		$newUser->image = 0;
		$newUser->last_seen = strftime("%Y-%m-%d %H:%M:%S", time());
		$newUser->date_joined = strftime("%Y-%m-%d %H:%M:%S", time());
		$newUser->date_modified = strftime("%Y-%m-%d %H:%M:%S", time());
		$newUser->save();

		$body = "Hi ".htmlspecialchars($newUser->first_name).",<br><br>";
	    $body .= "<p>Your password is <b>".$password."</b></p><br>";
	    $body .= "<p>If you wish to set a new password you can click forgot password on the login page.</p>";
 
        $outputMessage = "";
		if(tryToSendEmail($newUser->email, $newUser->first_name, $body)){
           $outputMessage = "New user should check their email, a password was sent. ";
           $outputMessage .= "If you don't see it in the inbox check it in the spam folder.";
        }else{
           $outputMessage = "A problem occurred, contact for help.";
        }
        
        $session->message($outputMessage);
        redirect(PUBLIC_FOLDER."jamruch_admin".DS."users");
	}
}

?>
<?php 
require_once "../layout/admin_header.php";
require_once "../layout/panel_header.php"; 
?>
<div id="users-page" class="m-3">
	<div class="container">
		<div class="page-header text-center row">
			<h1 class="col-9">users</h1>
			<span id="add-user-span" class="col-1" data-toggle="modal" data-target="#add-user-modal">
				<i class='fas fa-user-plus'></i>
			</span>
		</div>
		<div id="display-users">
			<table class="table table-dark">
				<thead>
					<tr>
						<th scope="col">Name</th>
						<th scope="col">Email</th>
						<th scope="col">Status</th>
						<th scope="col">Group</th>
						<th scope="col">Last Seen</th>
						<th scope="col"></th>
					</tr>
				</thead>
				<tbody>
					<tr id="current-user-tr">
						<td><?php echo htmlspecialchars($current->fullName()); ?></td>
						<td><?php echo htmlspecialchars($current->email); ?></td>
						<td><?php echo htmlspecialchars($current->active ? "activated": "not activated"); ?></td>
						<td><?php echo htmlspecialchars($current->user_group); ?></td>
						<td><?php echo htmlspecialchars(datetimeToTime($current->last_seen)); ?></td>
						<td></td>
					</tr>
					<?php foreach($users as $user){?>
						<tr data-user="<?php echo $user->id; ?>">
							<td><?php echo htmlspecialchars($user->fullName()); ?></td>
							<td><?php echo htmlspecialchars($user->email); ?></td>
							<td>
							<?php if(compareUsersPriviledges($current, $user)){?>
								<select name="activated" id="" class="form-control-sm user-changes">
									<option value="true" <?php if($user->active){ echo "selected"; } ?> >
										activated
									</option>
									<option value="false" <?php if(!$user->active){ echo "selected"; } ?> >
										not activated
									</option>
								</select>
							<?php } else { ?>
								<select name="activated" id="" class="form-control-sm">
									<option value="<?php echo $user->active ? 'true' : 'false'; ?>"  selected >
										<?php echo $user->active ? "activated" : "not activated";  ?>
									</option>
								</select>
							<?php } ?>
							</td>
							<td class="form-group">
								<?php if(compareUsersPriviledges($current, $user)){?>
								<select name="group" id="" class="form-control-sm user-changes">
									<?php foreach($enumValues as $enumValue){?>
										<option value="<?php echo htmlentities(trim($enumValue)); ?>" 
											<?php if(strtolower(htmlentities(trim($enumValue))) == strtolower(htmlentities(trim($user->user_group)))){ echo "selected"; }?> >
											<?php echo htmlentities(trim($enumValue)); ?>
										</option>
									<?php } ?>
								</select>
								<?php } else {?>
								<select name="group" id="" class="form-control-sm">
									<option value="<?php echo htmlentities(trim($user->user_group)); ?>" selected>
										<?php echo htmlentities(trim($user->user_group)); ?>
									</option>
								</select>
								<?php } ?>
							</td>
							<td><?php echo htmlspecialchars(datetimeToTime($user->last_seen)); ?></td>
							<td>
								<?php if(compareUsersPriviledges($current, $user)){?>
								<a href="delete_user.php"  class="text-danger delete-user">X</a>
								<?php } else { ?>
									<div class="text-warning">X</div>
								<?php } ?>
							</td>
						</tr>
					<?php } ?>
				</tbody>
			</table>
		</div>
		<div class="modal fade" id="add-user-modal" tabindex="-1" role="dialog" aria-labelledby="add-user-modal-label" aria-hidden="true">
		  <div class="modal-dialog" role="document">
		    <div class="modal-content">
		      <div class="modal-header">
		        <h5 class="modal-title" id="add-user-modal-label">Add User</h5>
		        <button type="button" class="close text-muted" data-dismiss="modal" aria-label="Close">
		          <span aria-hidden="true">&times;</span>
		        </button>
		      </div>
		      <div class="modal-body">
		        <form method="POST" action="<?php echo cleanURLForms($_SERVER['PHP_SELF']); ?>">
		          <div class="form-group">
		          	<div id="err-first-name" class="error-msg"><?php echo htmlspecialchars($errors['first-name'] ?? "");?></div>
		            <label for="first-name" class="col-form-label">first name</label>
		            <input type="text" class="form-control <?php echo inputErrCheck($errors['first-name'] ?? ""); ?>" id="first-name" placeholder="first name" name="first-name">
		          </div>
		          <div class="form-group">
		          	<div id="err-last-name" class="error-msg"><?php echo htmlspecialchars($errors['last-name'] ?? "");?></div>
		            <label for="last-name" class="col-form-label">last name</label>
		            <input type="text" class="form-control <?php echo inputErrCheck($errors['last-name'] ?? ""); ?>" id="last-name" placeholder="last name"  name="last-name">
		          </div>
		          <div class="form-group">
		          	<div id="err-email" class="error-msg"><?php echo htmlspecialchars($errors['email'] ?? "");?></div>
		            <label for="email" class="col-form-label">email</label>
		            <input type="text" class="form-control <?php echo inputErrCheck($errors['email'] ?? ""); ?>" id="email" placeholder="email" name="email">
		          </div>
		          <div class="form-group">
		          	<div id="err-email" class="error-msg"><?php echo htmlspecialchars($errors['user_group'] ?? "");?></div>
		            <label for="email" class="col-form-label">user group</label>
		            <select name="user-group" id="" class="form-control <?php echo inputErrCheck($errors['user-group'] ?? ""); ?>">
		            	<?php foreach($enumValues as $enumValue){?>
							<option value="<?php echo htmlentities(trim($enumValue)); ?>">
								<?php echo htmlentities(trim($enumValue)); ?>
							</option>
						<?php } ?>
		            </select>
		          </div>
		      </div>
		      <div class="modal-footer">
		      	<input type="hidden" id="add-user-token" name="token" value="<?php echo $session->createToken('addUserToken', 'addUserTimer'); ?>">
		        <input type="submit" value="Add User" name="add" class="btn btn-primary">
		        </form>
		      </div>
		    </div>
		  </div>
		</div>
		<div class="modal fade" id="confirm-changes-modal" tabindex="-1" role="dialog" aria-labelledby="confirm-changes-modal-CenterTitle" aria-hidden="true">
		  <div class="modal-dialog modal-dialog-centered" role="document">
		    <div class="modal-content">
		      <div class="modal-header">
		        <div class="modal-title text-center" id="confirm-changes-modal-LongTitle">
		        	In order to make changes enter your password.
		        </div>
		      </div>
		      <div class="modal-body">
		      	<form action="" method="POST" id="confirm-changes-form">
		        <div class="form-group">
		        	<div id="err-confirm-changes-pass" class="error-msg"></div>
		        	<label for="confirm-changes-pass">PASSWORD:</label>
		        	<input type="password" class="form-control" id="confirm-changes-pass" name="password">
		        </div>
		      </div>
		      <div class="modal-footer">
		        <button id="close-modify-user" type="button" class="btn btn-secondary" data-dismiss="modal">Close</button>
		        <input type="submit" class="btn btn-primary" id="confirm-changes-btn" name="confirm-changes-btn" value="Confirm">
		    	</form>
		      </div>
		    </div>
		  </div>
		</div>
		<div class="modal fade" id="confirm-delete-modal" tabindex="-1" role="dialog" aria-labelledby="confirm-delete-modal-CenterTitle" aria-hidden="true">
		  <div class="modal-dialog modal-dialog-centered" role="document">
		    <div class="modal-content">
		      <div class="modal-header">
		        <div class="modal-title text-center" id="confirm-delete-modal-LongTitle">
		        	In order to delete the user enter your password.
		        </div>
		      </div>
		      <div class="modal-body">
		      	<form action="" method="POST" id="confirm-delete-form">
		        <div class="form-group">
		        	<div id="err-confirm-delete-pass" class="error-msg"></div>
		        	<label for="confirm-delete-pass">PASSWORD:</label>
		        	<input type="password" class="form-control" id="confirm-delete-pass" name="password">
		        </div>
		      </div>
		      <div class="modal-footer">
		        <button id="close-delete-user" type="button" class="btn btn-secondary" data-dismiss="modal">Close</button>
		        <input type="submit" class="btn btn-primary" id="confirm-delete-btn" name="confirm-delete-btn" value="Confirm">
		    	</form>
		      </div>
		    </div>
		  </div>
		</div>
	</div>
</div>
<?php if(isset($errors) && !empty($errors)){ ?>
<script>
	window.addEventListener('DOMContentLoaded', ()=>{
		let addUser = document.querySelector('#add-user-span');
			addUser.click();
	});


</script>
<?php } ?>
<?php 
require_once "../layout/panel_footer.php"; 
require_once "../layout/admin_footer.php"; 
?>
